import sys
import os
import requests

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 14
project_path = file_path[0:end]
sys.path.append(project_path)
import pandas as pd
import mns_common.utils.data_frame_util as data_frame_util
import mns_common.api.kpl.common.kpl_common_field_constant as kpl_common_field_constant
from loguru import logger

BEST_CHOOSE = '7'
AREA = '6'
CONCEPT = '5'
INDUSTRY = '4'

PAGE_MAX_COUNT = 80

HIS_PAGE_MAX_COUNT = 70


# index_type= 4 行业   index_type= 5 概念  index_type= 6 地域 ndex_type= 7 精选板块
def get_plate_index(index_type):
    result = pd.DataFrame()
    page_number = 0
    page_index = 0
    headers = {
        "User-Agent": "Content-Type: application/x-www-form-urlencoded; charset=utf-8"
    }
    while True:
        r = requests.post("https://apphq.longhuvip.com/w1/api/index.php?"
                          "Index=" + str(page_index) + "&Order=1&PhoneOSNew=2&Type=1&VerSion=5.13.0.3&ZSType="
                          + str(index_type) +
                          "&a=RealRankingInfo&apiv=w35&c=ZhiShuRanking&st="
                          + str(PAGE_MAX_COUNT), headers=headers)

        data_json = r.json()
        data_concept = data_json['list']
        data_df_plate = pd.DataFrame(data_concept)
        if data_frame_util.is_empty(data_df_plate):
            break
        data_df_plate = kpl_common_field_constant.rename_plate_index(data_df_plate)
        result = pd.concat([result, data_df_plate])
        if data_df_plate.shape[0] < PAGE_MAX_COUNT:
            break
        else:
            page_number = page_number + 1
            page_index = page_number * PAGE_MAX_COUNT

    return result


# 板块股票组成# 精选板块 # 行业板块

# Order 排序参数
# st 分页最大数量
# index 股票排名index
def plate_detail_info(plate_code):
    index = 0
    result = None
    while True:
        url = (
                f"https://apphq.longhuvip.com/w1/api/index.php?"
                f"Index=" + str(index) +
                f"&IsKZZType=0"
                f"&IsZZ=0"
                f"&Order=1"
                f"&PhoneOSNew=3"
                f"&PlateID=" + str(plate_code) +
                f"&Token=e4b1267830dc99626a1e95394980d769&Type=6&UserID=2289803"
                f"&VerSion=5.11.0.3&a=ZhiShuStockList_W8&apiv=w33&c=ZhiShuRanking"
                f"&old=1&st=100")
        headers = {
            "User-Agent": "Content-Type: application/x-www-form-urlencoded; charset=utf-8"
        }
        r = requests.post(url, headers=headers)
        data_json = r.json()
        data_concept = data_json['list']
        count = data_json['Count']
        data_df = pd.DataFrame(data_concept)
        result = data_frame_util.merge_choose_data_no_drop(result, data_df)
        index = index + 100
        if count < index:
            break
    if data_frame_util.is_empty(result):
        return None
    result = kpl_common_field_constant.rename_kpl_plate_detail(result)
    return result


# 历史区间强度

# begin到end之间的强度
def get_plate_index_his(index, index_type, str_day, begin, end):
    url = "https://apphis.longhuvip.com/w1/api/index.php?Date" \
          "=" + str(str_day) + \
          "&Index=" + str(index) + \
          "&Order=1&PhoneOSNew=2" \
          "&REnd=" + str(end) + \
          "&RStart=" + str(begin) + \
          "&Type=1&VerSion=5.14.0.1" \
          "&ZSType=" + str(index_type) + \
          "&a=RealRankingInfo&apiv=w36&c=ZhiShuRanking" \
          "&st=" + str(HIS_PAGE_MAX_COUNT)

    headers = {
        "User-Agent": "Content-Type: application/x-www-form-urlencoded; charset=utf-8"
    }
    r = requests.post(url, headers=headers)
    data_json = r.json()
    data_concept = data_json['list']
    data_df_his = pd.DataFrame(data_concept)
    if data_frame_util.is_empty(data_df_his):
        return None
    data_df_his = kpl_common_field_constant.rename_plate_index(data_df_his)
    return data_df_his


# 获取开盘啦 股票入选概念原因
def get_kpl_concept_choose_reason(plate_id, symbol_list_str):
    try:
        response = requests.get(
            url="https://apphwshhq.longhuvip.com/w1/api/index.php",
            params={
                "PhoneOSNew": "2",
                "PlateID": plate_id,
                "Stocks": symbol_list_str,
                "VerSion": "5.21.0.3",
                "a": "PlateIntroduction_Info",
                "apiv": "w42",
                "c": "ZhiShuRanking"
            },
            headers={
                "User-Agent": "lhb/5.21.3 (com.kaipanla.www; build:0; iOS 18.6.2) Alamofire/4.9.1"
            }
        )

        json_result = response.json()
        symbol_list_reason = json_result.get('List')

        df_simple = pd.DataFrame(symbol_list_reason, columns=['symbol', 'choose_reason', 'flag', 'remark'])
        return df_simple
    except BaseException as e:
        logger.error("获取开盘啦股票入选原因异常:{},{},{}", plate_id, symbol_list_str, e)
        return pd.DataFrame()


if __name__ == '__main__':
    plate_id_test = '801133'
    symbol_list_str_test = "002017,002104,301678,003040,300689,300608,300698,600941,002313,002881,002467,300579,002355,300205,300638,002049"

    df_simple_test = get_kpl_concept_choose_reason(plate_id_test, symbol_list_str_test)

    df = plate_detail_info('801359')

    df = get_plate_index(7)
    print(df)
    data_df = get_plate_index_his(0, 7, '2024-04-24', '0925', '0930')
    print(data_df)



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 16
project_path = file_path[0:end]
sys.path.append(project_path)

import mns_common.api.akshare.stock_bid_ask_api as stock_bid_ask_api
from mns_common.constant.price_enum import PriceEnum
import mns_common.component.common_service_fun_api as common_service_fun_api
import mns_common.utils.date_handle_util as date_handle_util
from mns_common.db.MongodbUtil import MongodbUtil
import mns_common.constant.db_name_constant as db_name_constant
import mns_common.utils.data_frame_util as data_frame_util

mongodb_util = MongodbUtil('27017')

'''

'''


def get_trade_price(symbol, price_code, limit_chg):
    stock_bid_ask_df = stock_bid_ask_api.stock_bid_ask_em(symbol)
    wei_bi = list(stock_bid_ask_df['wei_bi'])[0]
    now_price = list(stock_bid_ask_df['now_price'])[0]
    if wei_bi == PriceEnum.ZT_WEI_BI.price_name:
        trade_price = list(stock_bid_ask_df['buy_1'])[0]
    elif wei_bi == PriceEnum.DT_WEI_BI.price_name:
        trade_price = list(stock_bid_ask_df['sell_1'])[0]
    elif price_code == PriceEnum.BUY_1.price_code:
        trade_price = list(stock_bid_ask_df['buy_1'])[0]
    elif price_code == PriceEnum.BUY_2.price_code:
        trade_price = list(stock_bid_ask_df['buy_2'])[0]
    elif price_code == PriceEnum.BUY_3.price_code:
        trade_price = list(stock_bid_ask_df['buy_3'])[0]
    elif price_code == PriceEnum.BUY_4.price_code:
        trade_price = list(stock_bid_ask_df['buy_4'])[0]
    elif price_code == PriceEnum.BUY_5.price_code:
        trade_price = list(stock_bid_ask_df['buy_5'])[0]

    elif price_code == PriceEnum.SELL_1.price_code:
        trade_price = list(stock_bid_ask_df['sell_1'])[0]
    elif price_code == PriceEnum.SELL_2.price_code:
        trade_price = list(stock_bid_ask_df['sell_2'])[0]
    elif price_code == PriceEnum.SELL_3.price_code:
        trade_price = list(stock_bid_ask_df['sell_3'])[0]
    elif price_code == PriceEnum.SELL_4.price_code:
        trade_price = list(stock_bid_ask_df['sell_4'])[0]
    elif price_code == PriceEnum.SELL_5.price_code:
        trade_price = list(stock_bid_ask_df['sell_5'])[0]

    elif price_code == PriceEnum.BUY_PRICE_LIMIT.price_code:
        trade_price = round(now_price * (1 + limit_chg), 2)
    elif price_code == PriceEnum.SEll_PRICE_LIMIT.price_code:
        trade_price = round(now_price * (1 - limit_chg), 2)

    elif price_code == PriceEnum.ZT_PRICE.price_code:
        trade_price = list(stock_bid_ask_df['zt_price'])[0]

    elif price_code == PriceEnum.DT_PRICE.price_code:
        trade_price = list(stock_bid_ask_df['dt_price'])[0]
    else:
        trade_price = list(stock_bid_ask_df['now_price'])[0]

    trade_price = round(trade_price, 2)
    return trade_price


# 计算涨停价格
def calculate_zt_price(last_close_price, symbol):
    classification = common_service_fun_api.classify_symbol_one(symbol)
    if classification in ['K', 'C']:
        zt_chg = 0.2
    elif classification in ['S', 'H']:
        zt_chg = 0.1
    elif classification in ['X']:
        zt_chg = 0.3
    else:
        zt_chg = 0.05

    zt_price = round((1 + zt_chg) * last_close_price, 2)
    return zt_price


# 获取最近一个交易日收盘价格
def get_last_close_price(symbol, str_day):
    if str_day is not None:
        query = {"symbol": symbol, 'date': date_handle_util.no_slash_date(str_day)}
        stock_qfq_daily_df = mongodb_util.find_query_data(db_name_constant.STOCK_QFQ_DAILY, query)
        if data_frame_util.is_empty(stock_qfq_daily_df):
            query_descend = {"symbol": symbol}
            stock_qfq_daily_df = mongodb_util.descend_query(query_descend,
                                                            db_name_constant.STOCK_QFQ_DAILY,
                                                            "date", 1)
    else:
        query_descend = {"symbol": symbol}
        stock_qfq_daily_df = mongodb_util.descend_query(query_descend,
                                                        db_name_constant.STOCK_QFQ_DAILY,
                                                        "date", 1)
    close = list(stock_qfq_daily_df['close'])[0]
    return close


if __name__ == '__main__':
    price = get_last_close_price('300085', None)
    print(price)



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 14
project_path = file_path[0:end]
sys.path.append(project_path)
import akshare as ak
from loguru import logger
import mns_common.utils.date_handle_util as date_handle_util


def stock_em_zt_pool_df(date):
    try:
        date = date_handle_util.no_slash_date(date)
        zt_df = ak.stock_zt_pool_em(date)
        if zt_df is None or zt_df.shape[0] == 0:
            return None
        zt_df.rename(columns={"序号": "index",
                              "代码": "symbol",
                              "名称": "name",
                              "最新价": "now_price",
                              "涨跌幅": "chg",
                              "成交额": "amount",
                              "流通市值": "flow_mv",
                              "总市值": "total_mv",
                              "换手率": "exchange",
                              "封板资金": "closure_funds",
                              "首次封板时间": "first_closure_time",
                              "最后封板时间": "last_closure_time",
                              "炸板次数": "frying_plates_numbers",
                              "涨停统计": "statistics",
                              "连板数": "connected_boards_numbers",
                              "所属行业": "industry"
                              }, inplace=True)
        zt_df.loc[zt_df['amount'] == '-', 'amount'] = 0
        zt_df.loc[zt_df['exchange'] == '-', 'exchange'] = 0
        zt_df.loc[zt_df['closure_funds'] == '-', 'closure_funds'] = 0
        return zt_df
    except BaseException as e:
        logger.error("同步股票涨停数据出现异常:{},{}", date, e)
        return None


if __name__ == '__main__':
    df = stock_em_zt_pool_df('2025-10-24')
    print(df)



from akshare.datasets import get_ths_js


def get_file_content_ths(file: str = "ths.js") -> str:
    """
    获取 JS 文件的内容
    :param file:  JS 文件名
    :type file: str
    :return: 文件内容
    :rtype: str
    """
    setting_file_path = get_ths_js(file)
    with open(setting_file_path) as f:
        file_data = f.read()
    return file_data



import requests

import mns_common.utils.data_frame_util as data_frame_util
import json
import datetime

import threading
from concurrent.futures import ThreadPoolExecutor
import mns_common.component.proxies.proxy_common_api as proxy_common_api
from loguru import logger
import concurrent.futures
import pandas as pd
import time
from concurrent.futures import ThreadPoolExecutor, as_completed
from threading import Lock

fields = ("f352,f2,f3,f5,f6,f8,f10,f11,f22,f12,f14,f15,f16,f17,"
          "f18,f20,f21,f26,f33,f34,f35,f62,f66,f69,f72,f100,f184,f211,f212"),
fs = "m:0 t:6,m:0 t:80,m:1 t:2,m:1 t:23,m:0 t:81 s:2048"


max_number = 5800
# 分页条数
PAGE_SIZE = 100


def get_stocks_num(pn, proxies, page_size, time_out):
    """
     获取单页股票数据
     """
    # 获取当前日期和时间
    current_time = datetime.datetime.now()

    # 将当前时间转换为时间戳（以毫秒为单位）
    current_timestamp_ms = int(current_time.timestamp() * 1000)

    url = "https://33.push2.eastmoney.com/api/qt/clist/get"
    params = {
        "cb": "jQuery1124046660442520420653_" + str(current_timestamp_ms),
        "pn": str(pn),
        "pz": str(page_size),  # 每页最大200条
        "po": "0",
        "np": "3",
        "ut": "bd1d9ddb04089700cf9c27f6f7426281",
        "fltt": "2",
        "invt": "2",
        "wbp2u": "|0|0|0|web",
        "fid": "f12",
        "fs": fs,
        "fields": fields,
        "_": current_timestamp_ms
    }
    try:
        if proxies is None:
            r = requests.get(url, params, timeout=time_out)
        else:
            r = requests.get(url, params, proxies=proxies, timeout=time_out)

        data_text = r.text

        begin_index_total = data_text.index('"total":')

        end_index_total = data_text.index('"diff"')

        total_number = int(data_text[begin_index_total + 8:end_index_total - 1])

        return total_number

    except Exception as e:
        logger.error("获取第{}页股票列表异常:{}", pn, str(e))
        return 0


def get_stock_page_data_time_out(pn, proxies, page_size, time_out):
    """
    获取单页股票数据
    """
    # 获取当前日期和时间
    current_time = datetime.datetime.now()

    # 将当前时间转换为时间戳（以毫秒为单位）
    current_timestamp_ms = int(current_time.timestamp() * 1000)

    url = "https://33.push2.eastmoney.com/api/qt/clist/get"
    params = {
        "cb": "jQuery1124046660442520420653_" + str(current_timestamp_ms),
        "pn": str(pn),
        "pz": str(page_size),  # 每页最大200条
        "po": "0",
        "np": "3",
        "ut": "bd1d9ddb04089700cf9c27f6f7426281",
        "fltt": "2",
        "invt": "2",
        "wbp2u": "|0|0|0|web",
        "fid": "f12",
        "fs": fs,
        "fields": fields,
        "_": current_timestamp_ms
    }
    try:
        if proxies is None:
            r = requests.get(url, params, timeout=time_out)
        else:
            r = requests.get(url, params, proxies=proxies, timeout=time_out)

        data_text = r.text
        if pn == 1:
            try:
                begin_index_total = data_text.index('"total":')

                end_index_total = data_text.index('"diff"')
                global max_number
                max_number = int(data_text[begin_index_total + 8:end_index_total - 1])
            except Exception as e:
                logger.error("获取第{}页股票列表异常:{}", pn, str(e))
                return pd.DataFrame()

        begin_index = data_text.index('[')
        end_index = data_text.index(']')
        data_json = data_text[begin_index:end_index + 1]
        data_json = json.loads(data_json)
        if data_json is None:
            return pd.DataFrame()
        else:
            result_df = pd.DataFrame(data_json)
            result_df['page_number'] = pn
            return result_df
    except Exception as e:
        logger.error("获取第{}页股票列表异常:{}", pn, str(e))
        return pd.DataFrame()


def repeated_acquisition_ask(per_page, max_number, time_out, max_workers=5):
    total_pages = (max_number + per_page - 1) // per_page  # 向上取整
    result_df = pd.DataFrame()
    df_lock = Lock()  # 线程安全的DataFrame合并锁

    def fetch_pages(page_nums):
        """单个线程处理一组页面，复用代理IP直到失效"""
        proxy_ip = proxy_common_api.generate_proxy_ip_api(1)
        proxies = {"https": proxy_ip, "http": proxy_ip}
        thread_results = []  # 线程内临时存储结果

        for page_num in page_nums:
            while True:  # 重试循环（复用当前IP）
                try:
                    page_df = get_stock_page_data_time_out(
                        page_num, proxies, per_page, time_out
                    )
                    if data_frame_util.is_not_empty(page_df):
                        logger.info("线程{} 页面{}获取成功（IP复用中）",
                                    threading.get_ident(), page_num)
                        thread_results.append(page_df)
                        break  # 成功后继续用当前IP处理下一页
                    else:
                        logger.warning("页面数据为空:{},重试中...", page_num)
                        # 数据为空，更换IP
                        proxy_ip = proxy_common_api.generate_proxy_ip_api(1)
                        proxies = {"https": proxy_ip, "http": proxy_ip}
                        time.sleep(0.2)
                except BaseException as e:
                    logger.error("线程{} 页面{}获取异常[{}]，更换IP重试",
                                 threading.get_ident(), page_num, str(e))
                    # 发生异常，更换IP
                    proxy_ip = proxy_common_api.generate_proxy_ip_api(1)
                    proxies = {"https": proxy_ip, "http": proxy_ip}
                    time.sleep(1)
        return thread_results

    # 页面分配：平均分配给每个线程
    def split_pages(total, workers):
        pages = list(range(1, total + 1))
        avg = total // workers
        remainder = total % workers
        split = []
        start = 0
        for i in range(workers):
            end = start + avg + (1 if i < remainder else 0)
            split.append(pages[start:end])
            start = end
        return split

    # 分配页面组
    page_groups = split_pages(total_pages, max_workers)

    # 多线程执行
    with ThreadPoolExecutor(max_workers=max_workers) as executor:
        futures = [executor.submit(fetch_pages, group) for group in page_groups]

        # 合并结果
        for future in as_completed(futures):
            try:
                thread_dfs = future.result()
                if thread_dfs:
                    with df_lock:
                        result_df = pd.concat([result_df] + thread_dfs, ignore_index=True)
            except Exception as e:
                logger.error("线程结果处理失败:{}", str(e))

    return result_df


def repeated_acquisition_ask_sync(time_out):
    per_page = PAGE_SIZE
    total_pages = (max_number + per_page - 1) // per_page  # 向上取整
    result_df = pd.DataFrame()
    now_page = 1
    proxy_ip = proxy_common_api.generate_proxy_ip_api(1)
    while now_page <= total_pages:
        proxies = {"https": proxy_ip,
                   "http": proxy_ip}
        try:
            page_df = get_stock_page_data_time_out(now_page, proxies, PAGE_SIZE, time_out)
            if data_frame_util.is_not_empty(page_df):
                result_df = pd.concat([page_df, result_df])
                logger.info("获取页面数据成功:{}", now_page)
                now_page = now_page + 1
            else:
                time.sleep(0.2)
                proxy_ip = proxy_common_api.generate_proxy_ip_api(1)
                logger.info("获取页面数据失败:{}", now_page)
        except BaseException as e:
            time.sleep(1)
            proxy_ip = proxy_common_api.generate_proxy_ip_api(1)
        # 示例调用
    return result_df


def repeated_acquisition_ask_async(time_out, max_number, num_threads, pages_per_thread):
    per_page = PAGE_SIZE
    total_pages = (max_number + per_page - 1) // per_page  # 向上取整
    result_df = pd.DataFrame()

    # 创建线程锁以确保线程安全
    df_lock = Lock()

    # 计算每个线程处理的页数范围
    def process_page_range(start_page, end_page, thread_id):
        nonlocal result_df
        local_df = pd.DataFrame()
        current_page = start_page
        proxy_ip = proxy_common_api.generate_proxy_ip_api(1)

        while current_page <= end_page and current_page <= total_pages:
            proxies = {"https": proxy_ip, "http": proxy_ip}
            try:
                page_df = get_stock_page_data_time_out(current_page, proxies, PAGE_SIZE, time_out)
                if data_frame_util.is_not_empty(page_df):
                    local_df = pd.concat([local_df, page_df])
                    logger.info("线程{}获取页面数据成功: {}", thread_id, current_page)
                    current_page += 1
                else:
                    time.sleep(0.2)
                    proxy_ip = proxy_common_api.generate_proxy_ip_api(1)
                    logger.info("线程{}获取页面数据失败: {}", thread_id, current_page)
            except BaseException as e:
                time.sleep(1)
                proxy_ip = proxy_common_api.generate_proxy_ip_api(1)
                logger.error("线程{}处理页面{}时发生错误: {}", thread_id, current_page, e)

        with df_lock:
            result_df = pd.concat([result_df, local_df])
        return len(local_df)

    # 计算每个线程的页面范围
    page_ranges = []
    for i in range(num_threads):
        start_page = i * pages_per_thread + 1
        end_page = (i + 1) * pages_per_thread
        if start_page > total_pages:
            break
        page_ranges.append((start_page, end_page, i + 1))

    # 使用线程池执行任务
    with concurrent.futures.ThreadPoolExecutor(max_workers=num_threads) as executor:
        # 提交所有任务
        futures = [
            executor.submit(process_page_range, start, end, tid)
            for start, end, tid in page_ranges
        ]

        # 等待所有任务完成并获取结果
        results = []
        for future in concurrent.futures.as_completed(futures):
            try:
                result = future.result()
                results.append(result)
            except Exception as e:
                logger.error("线程执行出错: {}", e)

    return rename_real_time_quotes_df(result_df)


def rename_real_time_quotes_df(temp_df):
    temp_df = temp_df.rename(columns={
        "f2": "now_price",
        "f3": "chg",
        "f5": "volume",
        "f6": "amount",
        "f8": "exchange",
        "f10": "quantity_ratio",
        "f22": "up_speed",
        "f11": "up_speed_05",
        "f12": "symbol",
        "f14": "name",
        "f15": "high",
        "f16": "low",
        "f17": "open",
        "f18": "yesterday_price",
        "f20": "total_mv",
        "f21": "flow_mv",
        "f26": "list_date",
        "f33": "wei_bi",
        "f34": "outer_disk",
        "f35": "inner_disk",
        "f62": "today_main_net_inflow",
        "f66": "super_large_order_net_inflow",
        "f69": "super_large_order_net_inflow_ratio",
        "f72": "large_order_net_inflow",
        # "f78": "medium_order_net_inflow",
        # "f84": "small_order_net_inflow",
        "f100": "industry",
        # "f103": "concept",
        "f184": "today_main_net_inflow_ratio",
        "f352": "average_price",
        "f211": "buy_1_num",
        "f212": "sell_1_num"
    })
    if data_frame_util.is_empty(temp_df):
        return pd.DataFrame()
    else:
        temp_df.loc[temp_df['buy_1_num'] == '-', 'buy_1_num'] = 0
        temp_df.loc[temp_df['sell_1_num'] == '-', 'sell_1_num'] = 0
        temp_df.loc[temp_df['up_speed_05'] == '-', 'up_speed_05'] = 0
        temp_df.loc[temp_df['up_speed'] == '-', 'up_speed'] = 0
        temp_df.loc[temp_df['average_price'] == '-', 'average_price'] = 0
        temp_df.loc[temp_df['wei_bi'] == '-', 'wei_bi'] = 0
        temp_df.loc[temp_df['yesterday_price'] == '-', 'yesterday_price'] = 0
        temp_df.loc[temp_df['now_price'] == '-', 'now_price'] = 0
        temp_df.loc[temp_df['chg'] == '-', 'chg'] = 0
        temp_df.loc[temp_df['volume'] == '-', 'volume'] = 0
        temp_df.loc[temp_df['amount'] == '-', 'amount'] = 0
        temp_df.loc[temp_df['exchange'] == '-', 'exchange'] = 0
        temp_df.loc[temp_df['quantity_ratio'] == '-', 'quantity_ratio'] = 0
        temp_df.loc[temp_df['high'] == '-', 'high'] = 0
        temp_df.loc[temp_df['low'] == '-', 'low'] = 0
        temp_df.loc[temp_df['open'] == '-', 'open'] = 0
        temp_df.loc[temp_df['total_mv'] == '-', 'total_mv'] = 0
        temp_df.loc[temp_df['flow_mv'] == '-', 'flow_mv'] = 0
        temp_df.loc[temp_df['inner_disk'] == '-', 'inner_disk'] = 0
        temp_df.loc[temp_df['outer_disk'] == '-', 'outer_disk'] = 0
        temp_df.loc[temp_df['today_main_net_inflow_ratio'] == '-', 'today_main_net_inflow_ratio'] = 0
        temp_df.loc[temp_df['today_main_net_inflow'] == '-', 'today_main_net_inflow'] = 0
        temp_df.loc[temp_df['super_large_order_net_inflow'] == '-', 'super_large_order_net_inflow'] = 0
        temp_df.loc[temp_df['super_large_order_net_inflow_ratio'] == '-', 'super_large_order_net_inflow_ratio'] = 0
        temp_df.loc[temp_df['large_order_net_inflow'] == '-', 'large_order_net_inflow'] = 0
        # temp_df.loc[temp_df['medium_order_net_inflow'] == '-', 'medium_order_net_inflow'] = 0
        # temp_df.loc[temp_df['small_order_net_inflow'] == '-', 'small_order_net_inflow'] = 0

        temp_df["list_date"] = pd.to_numeric(temp_df["list_date"], errors="coerce")
        temp_df["wei_bi"] = pd.to_numeric(temp_df["wei_bi"], errors="coerce")
        temp_df["average_price"] = pd.to_numeric(temp_df["average_price"], errors="coerce")
        temp_df["yesterday_price"] = pd.to_numeric(temp_df["yesterday_price"], errors="coerce")
        temp_df["now_price"] = pd.to_numeric(temp_df["now_price"], errors="coerce")
        temp_df["chg"] = pd.to_numeric(temp_df["chg"], errors="coerce")
        temp_df["volume"] = pd.to_numeric(temp_df["volume"], errors="coerce")
        temp_df["amount"] = pd.to_numeric(temp_df["amount"], errors="coerce")
        temp_df["exchange"] = pd.to_numeric(temp_df["exchange"], errors="coerce")
        temp_df["quantity_ratio"] = pd.to_numeric(temp_df["quantity_ratio"], errors="coerce")
        temp_df["high"] = pd.to_numeric(temp_df["high"], errors="coerce")
        temp_df["low"] = pd.to_numeric(temp_df["low"], errors="coerce")
        temp_df["open"] = pd.to_numeric(temp_df["open"], errors="coerce")
        temp_df["total_mv"] = pd.to_numeric(temp_df["total_mv"], errors="coerce")
        temp_df["flow_mv"] = pd.to_numeric(temp_df["flow_mv"], errors="coerce")
        temp_df["outer_disk"] = pd.to_numeric(temp_df["outer_disk"], errors="coerce")
        temp_df["inner_disk"] = pd.to_numeric(temp_df["inner_disk"], errors="coerce")
        temp_df["today_main_net_inflow"] = pd.to_numeric(temp_df["today_main_net_inflow"], errors="coerce")
        temp_df["super_large_order_net_inflow"] = pd.to_numeric(temp_df["super_large_order_net_inflow"],
                                                                errors="coerce")
        temp_df["super_large_order_net_inflow_ratio"] = pd.to_numeric(temp_df["super_large_order_net_inflow_ratio"],
                                                                      errors="coerce")
        temp_df["large_order_net_inflow"] = pd.to_numeric(temp_df["large_order_net_inflow"],
                                                          errors="coerce")
        # temp_df["medium_order_net_inflow"] = pd.to_numeric(temp_df["medium_order_net_inflow"],
        #                                                    errors="coerce")
        # temp_df["small_order_net_inflow"] = pd.to_numeric(temp_df["small_order_net_inflow"], errors="coerce")

        # 大单比例
        temp_df['large_order_net_inflow_ratio'] = round((temp_df['large_order_net_inflow'] / temp_df['amount']) * 100,
                                                        2)

        # 外盘是内盘倍数
        temp_df['disk_ratio'] = round((temp_df['outer_disk'] - temp_df['inner_disk']) / temp_df['inner_disk'], 2)
        # 只有外盘没有内盘
        temp_df.loc[temp_df["inner_disk"] == 0, ['disk_ratio']] = 1688
        temp_df = temp_df.sort_values(by=['chg'], ascending=False)
        return temp_df


def get_stock_real_time_quotes(time_out, pages_per_thread):
    try_numer = 3
    while try_numer > 0:
        proxy_ip = proxy_common_api.generate_proxy_ip_api(1)
        proxies = {"https": proxy_ip,
                   "http": proxy_ip}

        total_number = get_stocks_num(1, proxies, 20, time_out)
        if total_number > 0:
            break
        try_numer = try_numer - 1
    if total_number == 0:
        return pd.DataFrame()

    total_pages = (max_number + PAGE_SIZE - 1) // PAGE_SIZE  # 向上取整

    num_threads = int((total_pages / pages_per_thread) + 1)
    return repeated_acquisition_ask_async(time_out, max_number, num_threads, pages_per_thread)


if __name__ == '__main__':

    while True:
        # proxy_ip = proxy_common_api.generate_proxy_ip_api(1)
        # proxies = {"https": proxy_ip,
        #            "http": proxy_ip}
        time_out = 10  # Set the timeout value
        result = get_stock_real_time_quotes(time_out, 10)
        print(result)



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 21
project_path = file_path[0:end]
sys.path.append(project_path)
from loguru import logger
import csv
import requests
import pandas as pd
import mns_common.component.em.em_stock_info_api as em_stock_info_api
from functools import lru_cache
import mns_common.utils.data_frame_util as data_frame_util


@lru_cache()
def get_us_stock_info():
    # 东财美股列表
    em_us_stock_info_df = em_stock_info_api.get_us_stock_info()
    em_us_stock_info_df['symbol'] = em_us_stock_info_df['symbol'].str.replace('_', '-')
    em_us_stock_info_df = em_us_stock_info_df.loc[em_us_stock_info_df['total_mv'] != 0]

    if data_frame_util.is_not_empty(em_us_stock_info_df):
        em_us_stock_info_df.fillna({'list_date': 10000101}, inplace=True)
        em_us_stock_info_df = em_us_stock_info_df[['symbol', 'name', 'list_date']]

    # alpha 股票名单
    alpha_us_stock_info = get_us_alpha_stock_list()
    alpha_us_stock_info = alpha_us_stock_info.loc[alpha_us_stock_info['assetType'] == 'Stock']
    if data_frame_util.is_not_empty(alpha_us_stock_info):
        alpha_us_stock_info.fillna({'list_date': '1000-01-01'}, inplace=True)
        alpha_us_stock_info = alpha_us_stock_info[['symbol', 'name', 'list_date']]

        alpha_us_stock_info['list_date'] = alpha_us_stock_info['list_date'].astype(str).str.replace('-', '').astype(int)

    us_stock_result_df = pd.concat([alpha_us_stock_info, em_us_stock_info_df])
    us_stock_result_df.drop_duplicates(subset=['symbol'], inplace=True)

    return us_stock_result_df


@lru_cache()
def get_us_etf_info():
    us_etf_info_df = em_stock_info_api.get_us_etf_info()
    if data_frame_util.is_not_empty(us_etf_info_df):
        us_etf_info_df.fillna({'list_date': 10000101}, inplace=True)
        us_etf_info_df = us_etf_info_df[['symbol', 'name', 'list_date']]

    # alpha ETF名单
    alpha_us_etf_info = get_us_alpha_stock_list()
    alpha_us_etf_info = alpha_us_etf_info.loc[alpha_us_etf_info['assetType'] == 'ETF']
    if data_frame_util.is_not_empty(alpha_us_etf_info):
        alpha_us_etf_info.fillna({'list_date': '1000-01-01'}, inplace=True)
        alpha_us_etf_info = alpha_us_etf_info[['symbol', 'name', 'list_date']]

        alpha_us_etf_info['list_date'] = alpha_us_etf_info['list_date'].astype(str).str.replace('-', '').astype(int)
    us_etf_result_df = pd.concat([us_etf_info_df, alpha_us_etf_info])
    us_etf_result_df.drop_duplicates(subset=['symbol'], inplace=True)

    return us_etf_result_df


# 退市 https://www.alphavantage.co/query?function=LISTING_STATUS&date=2012-07-10&state=delisted&apikey=QODR3TBYB2U4M9YR
@lru_cache()
def get_us_alpha_stock_list():
    try:
        # replace the "demo" apikey below with your own key from https://www.alphavantage.co/support/#api-key
        CSV_URL = 'https://www.alphavantage.co/query?function=LISTING_STATUS&apikey=demo'
        with requests.Session() as s:
            download = s.get(CSV_URL)
            decoded_content = download.content.decode('utf-8')
            cr = csv.reader(decoded_content.splitlines(), delimiter=',')
            my_list = list(cr)
            # 提取列名（第1行）
            columns = my_list[0]
            # 提取数据（第2行及以后）
            values = my_list[1:]

            # 转换为 DataFrame
            df = pd.DataFrame(values, columns=columns)
            df = df.rename(columns={'ipoDate': 'list_date'})
            if data_frame_util.is_not_empty(df):
                df.to_csv(r'D:\mns\mns-common\mns_common\component\us\listing_status.csv', index=False, encoding='gbk')
            return df
    except BaseException as e:
        logger.error("下载出现异常:{},", e)
        df = pd.read_csv(r'D:\mns\mns-common\mns_common\component\us\listing_status.csv', encoding='utf-8')
        df = df.rename(columns={'ipoDate': 'list_date'})
        return df


def get_us_alpha_stock_de_list():
    try:
        # replace the "demo" apikey below with your own key from https://www.alphavantage.co/support/#api-key
        CSV_URL = 'https://www.alphavantage.co/query?function=LISTING_STATUS&date=2025-08-02&state=delisted&apikey=QODR3TBYB2U4M9YR'
        with requests.Session() as s:
            download = s.get(CSV_URL)
            decoded_content = download.content.decode('utf-8')
            cr = csv.reader(decoded_content.splitlines(), delimiter=',')
            my_list = list(cr)
            # 提取列名（第1行）
            columns = my_list[0]
            # 提取数据（第2行及以后）
            values = my_list[1:]

            # 转换为 DataFrame
            df = pd.DataFrame(values, columns=columns)
            df = df.rename(columns={'ipoDate': 'list_date'})
            if data_frame_util.is_not_empty(df):
                df.to_csv(r'D:\mns\mns-common\mns_common\component\us\de_list_status.csv', index=False, encoding='gbk')
            return df
    except BaseException as e:
        logger.error("下载出现异常:{},", e)
        df = pd.read_csv(r'D:\mns\mns-common\mns_common\component\us\de_list_status.csv', encoding='utf-8')
        df = df.rename(columns={'ipoDate': 'list_date'})
        return df


if __name__ == '__main__':
    # get_us_alpha_stock_de_list()
    df_test = get_us_stock_info()
    df_test.drop_duplicates(subset=['symbol'], inplace=True)
    print(df_test)
    get_us_alpha_stock_de_list()



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 14
project_path = file_path[0:end]
sys.path.append(project_path)
from loguru import logger
import pywencai
import mns_common.utils.data_frame_util as data_frame_util
import mns_common.component.cookie.cookie_info_service as cookie_info_service
'''

# https://github.com/zsrl/pywencai 文档
# stock	股票
# zhishu	指数
# fund	基金
# hkstock	港股
# usstock	美股
# threeboard	新三板
# conbond	可转债
# insurance	保险
# futures	期货
# lccp	理财
# foreign_exchange	外汇
'''


def wen_cai_api(question, q_type):
    cookie = cookie_info_service.get_ths_cookie()
    response = pywencai.get(question=question, loop=True, query_type=q_type, cookie=cookie)
    return response


# 获取同花顺概念指数 by wen_cai
def get_concept_index_by_wen_cai():
    try:
        concept_index_df = wen_cai_api('同花顺概念指数', 'zhishu')
        concept_index_df.columns = ["code",
                                    "concept_name",
                                    "price",
                                    "chg",
                                    "detail",
                                    "market_code",
                                    "concept_code"]
        return concept_index_df
    except BaseException as e:
        logger.error("通过问财获取概念指数异常:{}", e)
        return None


# 获取同花顺行业指数 by wen_cai
def get_industry_index_by_wen_cai():
    try:
        industry_index_df = wen_cai_api('同花顺行业指数', 'zhishu')
        industry_index_df.columns = ["code",
                                     "industry_name",
                                     "price",
                                     "chg",
                                     "detail",
                                     "industry_class",
                                     "market_code",
                                     "industry_code"]
        if data_frame_util.is_not_empty(industry_index_df):
            industry_index_df = industry_index_df.loc[industry_index_df['industry_class'].isin([
                '二级行业', '三级行业'
            ])]
            return industry_index_df
        else:
            return None
    except BaseException as e:
        logger.error("通过问财获取行业指数异常:{}", e)
        return None


# 获取概念股票组成详情 通过问财
def get_concept_detail_by_wen_cai(concept_name):
    try:
        concept_name = concept_name.replace("（", "(")
        concept_name = concept_name.replace("）", ")")
        concept_name = concept_name.replace(" ", "")
        concept_all_detail_df = wen_cai_api("所属同花顺概念包含" + concept_name, 'stock')
        if data_frame_util.is_empty(concept_all_detail_df):
            return None
        if len(concept_all_detail_df.columns) == 9:
            concept_all_detail_df.columns = ["code",
                                             "name",
                                             "price",
                                             "chg",
                                             "concept_detail",
                                             "concept_num",
                                             "flow_mv",
                                             "market_code",
                                             'symbol']
            concept_all_detail_df['concept_name'] = concept_name
            concept_all_detail_df['explain'] = ''
            concept_all_detail_df['explain_url'] = ''
        if len(concept_all_detail_df.columns) == 11:
            concept_all_detail_df.columns = ["code",
                                             "name",
                                             "price",
                                             "chg",
                                             "concept_name",
                                             "explain",
                                             "explain_url",
                                             "concept_num",
                                             "flow_mv",
                                             "market_code",
                                             'symbol']
            concept_all_detail_df['concept_detail'] = ''
        return concept_all_detail_df
    except BaseException as e:
        logger.error("通过问财获取概念组成详情异常:{},{}", e, concept_name)
        return None


if __name__ == '__main__':
    zt_df = wen_cai_api('001203涨停分析', 'stock', )
    print(zt_df)
    # concept_detail_df = get_concept_detail_by_wen_cai("光纤概念")
    # concept_df = get_concept_index_by_wen_cai()
    # print(concept_df)
    # industry_index = get_industry_index_by_wen_cai()
    # print(industry_index)



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 16
project_path = file_path[0:end]
sys.path.append(project_path)
import mns_common.utils.date_handle_util as date_handle_util
from loguru import logger
import mns_common.utils.data_frame_util as data_frame_util
from functools import lru_cache
from mns_common.db.MongodbUtil import MongodbUtil
import mns_common.constant.db_name_constant as db_name_constant

mongodb_util = MongodbUtil('27017')

"""
Date: 2024/4/29 15:00
Desc: 东方财富网-数据中心-特色数据-停复牌信息
https://data.eastmoney.com/tfpxx/
"""

import pandas as pd
import requests


def stock_tfp_em(date: str = "20240426") -> pd.DataFrame:
    """
    东方财富网-数据中心-特色数据-停复牌信息
    https://data.eastmoney.com/tfpxx/
    :param date: specific date as "2020-03-19"
    :type date: str
    :return: 停复牌信息表
    :rtype: pandas.DataFrame
    """
    url = "https://datacenter-web.eastmoney.com/api/data/v1/get"
    params = {
        "sortColumns": "SUSPEND_START_DATE",
        "sortTypes": "-1",
        "pageSize": "500",
        "pageNumber": "1",
        "reportName": "RPT_CUSTOM_SUSPEND_DATA_INTERFACE",
        "columns": "ALL",
        "source": "WEB",
        "client": "WEB",
        "filter": f"""(MARKET="全部")(DATETIME='{"-".join([date[:4], date[4:6], date[6:]])}')""",
    }
    r = requests.get(url, params=params)
    data_json = r.json()
    total_page = data_json["result"]["pages"]
    big_df = pd.DataFrame()
    for page in range(1, total_page + 1):
        params.update({"pageNumber": page})
        r = requests.get(url, params=params)
        data_json = r.json()
        temp_df = pd.DataFrame(data_json["result"]["data"])
        big_df = pd.concat(objs=[big_df, temp_df], ignore_index=True)

    big_df.reset_index(inplace=True)

    big_df["SUSPEND_START_TIME"] = pd.to_datetime(big_df["SUSPEND_START_TIME"], errors="coerce").dt.date
    big_df["SUSPEND_END_TIME"] = pd.to_datetime(
        big_df["SUSPEND_END_TIME"], errors="coerce"
    ).dt.date

    big_df["SUSPEND_START_DATE"] = pd.to_datetime(
        big_df["SUSPEND_START_DATE"], errors="coerce"
    ).dt.date
    big_df["PREDICT_RESUME_DATE"] = pd.to_datetime(
        big_df["PREDICT_RESUME_DATE"], errors="coerce"
    ).dt.date

    big_df = big_df[['index', 'SECURITY_CODE', 'SECURITY_NAME_ABBR', 'SUSPEND_START_TIME',
                     'SUSPEND_END_TIME', 'SUSPEND_EXPIRE', 'SUSPEND_REASON', 'TRADE_MARKET',
                     'SUSPEND_START_DATE',
                     'PREDICT_RESUME_DATE'
                     ]]

    return big_df


def get_stock_tfp_by_day(str_day):
    stock_tfp_em_df = stock_tfp_em(date_handle_util.no_slash_date(str_day))
    stock_tfp_em_df = stock_tfp_em_df.rename(
        columns={'index': 'index',
                 'SECURITY_CODE': 'symbol',
                 'SECURITY_NAME_ABBR': 'name',
                 'SUSPEND_START_TIME': 'sus_begin_time',
                 'SUSPEND_END_TIME': 'sus_end_time',

                 'SUSPEND_START_DATE': 'sus_begin_date',
                 'PREDICT_RESUME_DATE': 'resume_time',

                 'SUSPEND_EXPIRE': 'sus_period',
                 'SUSPEND_REASON': 'sus_reason',
                 'TRADE_MARKET': 'market',

                 })
    return stock_tfp_em_df


# 获取停牌股票列表
@lru_cache(maxsize=None)
def get_stock_tfp_symbol_list_by_day(str_day):
    try:
        stock_tfp_em_df = get_stock_tfp_by_day(str_day)
        if data_frame_util.is_not_empty(stock_tfp_em_df):
            return list(stock_tfp_em_df['symbol'])
        else:
            return ['666666']

    except BaseException as e:
        logger.error("获取停牌信息异常:{}", e)
        return ['666666']


@lru_cache(maxsize=None)
def get_stock_tfp_symbol_from_db(str_day):
    try:
        query = {'str_day': str_day}
        stock_tfp_df = mongodb_util.find_query_data(db_name_constant.STOCK_TFP_INFO, query)
        if data_frame_util.is_not_empty(stock_tfp_df):
            return list(stock_tfp_df['symbol'])
        else:
            return ['666666']
    except BaseException as e:
        logger.error("获取停牌信息异常:{}", e)
        return ['666666']


if __name__ == '__main__':
    get_stock_tfp_symbol_list_by_day('2025-06-21')



import os
import sys

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 16
project_path = file_path[0:end]
sys.path.append(project_path)
import pandas as pd
from loguru import logger
import requests
import time
import numpy as np
import mns_common.component.proxies.proxy_common_api as proxy_common_api
import concurrent.futures
from concurrent.futures import ThreadPoolExecutor
from threading import Lock
import mns_common.utils.data_frame_util as data_frame_util
import json
import mns_common.component.cookie.cookie_info_service as cookie_info_service

# 最大返回条数
max_number = 4500
# 最小返回条数
min_number = 4400
# 分页条数
page_number = 100

fields = ("f352,f2,f3,f5,f6,f8,f10,f11,f22,f12,f14,f15,f16,f17,f18,f20,f21,f26,"
          "f33,f34,f35,f62,f66,f69,f72,f100,f184,f211,f212")


def hk_real_time_quotes_page_df(cookie, pn, proxies):
    try:
        headers = {
            'Cookie': cookie
        }

        current_timestamp = str(int(round(time.time() * 1000, 0)))

        url_new = ('https://61.push2.eastmoney.com/api/qt/clist/get?cb=jQuery112409497467688484127_' + str(
            current_timestamp) +
                   '&pn=' + str(pn) +
                   '&pz=50000'
                   '&po=1'
                   '&np=3'
                   '&ut=bd1d9ddb04089700cf9c27f6f7426281'
                   '&fltt=2'
                   '&invt=2'
                   '&wbp2u=4253366368931142|0|1|0|web'
                   '&fid=f12'
                   '&fs=m:116+t:3,m:116+t:4,m:116+t:1,m:116+t:2'
                   '&fields=' + fields +
                   '&_=' + str(current_timestamp))

        if proxies is None:
            r = requests.get(url_new, headers=headers)
        else:
            r = requests.get(url_new, headers=headers, proxies=proxies)
        result = r.content.decode("utf-8")

        if pn == 1:
            try:
                begin_index_total = result.index('"total":')

                end_index_total = result.index('"diff"')
                global max_number
                max_number = int(result[begin_index_total + 8:end_index_total - 1])
            except Exception as e:
                logger.error(f"获取第{pn}页港股列表异常: {e}")
                return pd.DataFrame()

        startIndex = result.index('"diff"')
        endIndex = result.index('}]}')

        result = result[startIndex + 7:endIndex + 2]

        data_json = json.loads(result)

        temp_df = pd.DataFrame(data_json)

        temp_df = temp_df.rename(columns={

            "f12": "symbol",
            "f14": "name",
            "f3": "chg",
            "f2": "now_price",
            "f5": "volume",
            "f6": "amount",
            "f8": "exchange",
            "f10": "quantity_ratio",
            "f22": "up_speed",
            "f11": "up_speed_05",

            "f15": "high",
            "f16": "low",
            "f17": "open",
            "f18": "yesterday_price",
            "f20": "total_mv",
            "f21": "flow_mv",
            "f26": "list_date",
            "f33": "wei_bi",
            "f34": "outer_disk",
            "f35": "inner_disk",
            "f62": "today_main_net_inflow",
            "f66": "super_large_order_net_inflow",
            "f69": "super_large_order_net_inflow_ratio",
            "f72": "large_order_net_inflow",
            # "f78": "medium_order_net_inflow",
            # "f84": "small_order_net_inflow",
            "f100": "industry",
            # "f103": "concept",
            "f184": "today_main_net_inflow_ratio",
            "f352": "average_price",
            "f211": "buy_1_num",
            "f212": "sell_1_num"
        })
        temp_df.loc[temp_df['buy_1_num'] == '-', 'buy_1_num'] = 0
        temp_df.loc[temp_df['sell_1_num'] == '-', 'sell_1_num'] = 0
        temp_df.loc[temp_df['up_speed_05'] == '-', 'up_speed_05'] = 0
        temp_df.loc[temp_df['up_speed'] == '-', 'up_speed'] = 0
        temp_df.loc[temp_df['average_price'] == '-', 'average_price'] = 0
        temp_df.loc[temp_df['wei_bi'] == '-', 'wei_bi'] = 0
        temp_df.loc[temp_df['yesterday_price'] == '-', 'yesterday_price'] = 0
        temp_df.loc[temp_df['now_price'] == '-', 'now_price'] = 0
        temp_df.loc[temp_df['chg'] == '-', 'chg'] = 0
        temp_df.loc[temp_df['volume'] == '-', 'volume'] = 0
        temp_df.loc[temp_df['amount'] == '-', 'amount'] = 0
        temp_df.loc[temp_df['exchange'] == '-', 'exchange'] = 0
        temp_df.loc[temp_df['quantity_ratio'] == '-', 'quantity_ratio'] = 0
        temp_df.loc[temp_df['high'] == '-', 'high'] = 0
        temp_df.loc[temp_df['low'] == '-', 'low'] = 0
        temp_df.loc[temp_df['open'] == '-', 'open'] = 0
        temp_df.loc[temp_df['total_mv'] == '-', 'total_mv'] = 0
        temp_df.loc[temp_df['flow_mv'] == '-', 'flow_mv'] = 0
        temp_df.loc[temp_df['inner_disk'] == '-', 'inner_disk'] = 0
        temp_df.loc[temp_df['outer_disk'] == '-', 'outer_disk'] = 0
        temp_df.loc[temp_df['today_main_net_inflow_ratio'] == '-', 'today_main_net_inflow_ratio'] = 0
        temp_df.loc[temp_df['today_main_net_inflow'] == '-', 'today_main_net_inflow'] = 0
        temp_df.loc[temp_df['super_large_order_net_inflow'] == '-', 'super_large_order_net_inflow'] = 0
        temp_df.loc[temp_df['super_large_order_net_inflow_ratio'] == '-', 'super_large_order_net_inflow_ratio'] = 0
        temp_df.loc[temp_df['large_order_net_inflow'] == '-', 'large_order_net_inflow'] = 0
        # temp_df.loc[temp_df['medium_order_net_inflow'] == '-', 'medium_order_net_inflow'] = 0
        # temp_df.loc[temp_df['small_order_net_inflow'] == '-', 'small_order_net_inflow'] = 0

        temp_df["list_date"] = pd.to_numeric(temp_df["list_date"], errors="coerce")
        temp_df["wei_bi"] = pd.to_numeric(temp_df["wei_bi"], errors="coerce")
        temp_df["average_price"] = pd.to_numeric(temp_df["average_price"], errors="coerce")
        temp_df["yesterday_price"] = pd.to_numeric(temp_df["yesterday_price"], errors="coerce")
        temp_df["now_price"] = pd.to_numeric(temp_df["now_price"], errors="coerce")
        temp_df["chg"] = pd.to_numeric(temp_df["chg"], errors="coerce")
        temp_df["volume"] = pd.to_numeric(temp_df["volume"], errors="coerce")
        temp_df["amount"] = pd.to_numeric(temp_df["amount"], errors="coerce")
        temp_df["exchange"] = pd.to_numeric(temp_df["exchange"], errors="coerce")
        temp_df["quantity_ratio"] = pd.to_numeric(temp_df["quantity_ratio"], errors="coerce")
        temp_df["high"] = pd.to_numeric(temp_df["high"], errors="coerce")
        temp_df["low"] = pd.to_numeric(temp_df["low"], errors="coerce")
        temp_df["open"] = pd.to_numeric(temp_df["open"], errors="coerce")
        temp_df["total_mv"] = pd.to_numeric(temp_df["total_mv"], errors="coerce")
        temp_df["flow_mv"] = pd.to_numeric(temp_df["flow_mv"], errors="coerce")
        temp_df["outer_disk"] = pd.to_numeric(temp_df["outer_disk"], errors="coerce")
        temp_df["inner_disk"] = pd.to_numeric(temp_df["inner_disk"], errors="coerce")
        temp_df["today_main_net_inflow"] = pd.to_numeric(temp_df["today_main_net_inflow"], errors="coerce")
        temp_df["super_large_order_net_inflow"] = pd.to_numeric(temp_df["super_large_order_net_inflow"],
                                                                errors="coerce")
        temp_df["super_large_order_net_inflow_ratio"] = pd.to_numeric(temp_df["super_large_order_net_inflow_ratio"],
                                                                      errors="coerce")
        temp_df["large_order_net_inflow"] = pd.to_numeric(temp_df["large_order_net_inflow"],
                                                          errors="coerce")
        # temp_df["medium_order_net_inflow"] = pd.to_numeric(temp_df["medium_order_net_inflow"],
        #                                                    errors="coerce")
        # temp_df["small_order_net_inflow"] = pd.to_numeric(temp_df["small_order_net_inflow"], errors="coerce")

        # 大单比例
        temp_df['large_order_net_inflow_ratio'] = round((temp_df['large_order_net_inflow'] / temp_df['amount']) * 100,
                                                        2)

        # 外盘是内盘倍数
        temp_df['disk_ratio'] = round((temp_df['outer_disk'] - temp_df['inner_disk']) / temp_df['inner_disk'], 2)
        # 只有外盘没有内盘
        temp_df.loc[temp_df["inner_disk"] == 0, ['disk_ratio']] = 1688
        temp_df['disk_diff_amount'] = round(
            (temp_df['outer_disk'] - temp_df['inner_disk']) * temp_df[
                "average_price"],
            2)
        return temp_df
    except Exception as e:
        logger.error("获取港股列表,实时行情异常:{}", e)
        return pd.DataFrame()


def thread_pool_executor(cookie, proxies):
    """
       使用多线程获取所有ETF数据
       """
    # 计算总页数，假设总共有1000条数据，每页200条

    per_page = page_number
    total_pages = (max_number + per_page - 1) // per_page  # 向上取整

    # 创建线程池
    with ThreadPoolExecutor(max_workers=3) as executor:
        # 提交任务，获取每页数据
        futures = [executor.submit(hk_real_time_quotes_page_df, cookie, pn, proxies)
                   for pn in range(1, total_pages + 1)]

        # 收集结果
        results = []
        for future in futures:
            result = future.result()
            if not result.empty:
                results.append(result)

    # 合并所有页面的数据
    if results:
        return pd.concat(results, ignore_index=True)
    else:
        return pd.DataFrame()


def get_hk_real_time_quotes(cookie, proxies):
    # 获取第一页数据
    page_one_df = hk_real_time_quotes_page_df(cookie, 1, proxies)
    # 数据接口正常返回5600以上的数量
    if page_one_df.shape[0] > min_number:
        page_one_df.drop_duplicates('symbol', keep='last', inplace=True)
        return page_one_df
    else:
        page_df = thread_pool_executor(cookie, proxies)
        page_df.drop_duplicates('symbol', keep='last', inplace=True)
        return page_df





if __name__ == '__main__':
    em_cookie_test = cookie_info_service.get_em_cookie()
    test_df = get_ggt_real_time_quotes(em_cookie_test, 30, 6)
    print(test_df)



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 14
project_path = file_path[0:end]
sys.path.append(project_path)

import requests
from bs4 import BeautifulSoup
import pandas as pd
from loguru import logger


def get_hk_company_info(symbol, ths_cookie):
    symbol_copy = symbol
    symbol = symbol[1:5]
    symbol = "HK" + symbol
    url = "https://basic.10jqka.com.cn/new/" + symbol + "/company.html"

    headers = {
        "Accept": "text/html,application/xhtml+xml,application/xml;q=0.9,image/avif,image/webp,image/apng,*/*;q=0.8,application/signed-exchange;v=b3;q=0.7",
        "Accept-Language": "zh-CN,zh;q=0.9",
        "Cache-Control": "max-age=0",
        "Connection": "keep-alive",
        "Referer": "https://basic.10jqka.com.cn/new/HK1456/news.html",
        "Sec-Fetch-Dest": "document",
        "Sec-Fetch-Mode": "navigate",
        "Sec-Fetch-Site": "same-origin",
        "Sec-Fetch-User": "?1",
        "Upgrade-Insecure-Requests": "1",
        "User-Agent": "Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_7) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/129.0.0.0 Safari/537.36",
        "sec-ch-ua": "\"Google Chrome\";v=\"129\", \"Not=A?Brand\";v=\"8\", \"Chromium\";v=\"129\"",
        "sec-ch-ua-mobile": "?0",
        "sec-ch-ua-platform": "\"macOS\"",
        "cookie": ths_cookie
    }
    cookies = {
        "Hm_lvt_722143063e4892925903024537075d0d": "1728263496",
        "Hm_lvt_929f8b362150b1f77b477230541dbbc2": "1728263496",
        "Hm_lvt_78c58f01938e4d85eaf619eae71b4ed1": "1728263496",
        "u_ukey": "A10702B8689642C6BE607730E11E6E4A",
        "u_uver": "1.0.0",
        "u_dpass": "mZuXjNOJ5najLo9im8e7OFWfVDerAPcR%2F4NwI5iI52Z9Il1%2FHk%2FIWnu2ARoy1hTUHi80LrSsTFH9a%2B6rtRvqGg%3D%3D",
        "u_did": "5DC9AE36023C4F578A90F6BD333F757C",
        "u_ttype": "WEB",
        "ttype": "WEB",
        "user": "MDq%2BsNDQcE06Ok5vbmU6NTAwOjYxMzk4NTQ0ODo1LDEsMjM7NiwxLDIzOzcsMTExMTExMTExMTEwLDIzOzgsMTExMTAxMTEwMDAwMTExMTEwMDEwMDEwMDEwMDAwMDAsMjM7MzMsMDAwMTAwMDAwMDAwLDIzOzM2LDEwMDExMTExMDAwMDExMDAxMDExMTExMSwyMzs0NiwwMDAwMTExMTEwMDAwMDExMTExMTExMTEsMjM7NTEsMTEwMDAwMDAwMDAwMDAwMCwyMzs1OCwwMDAwMDAwMDAwMDAwMDAwMSwyMzs3OCwxLDIzOzg3LDAwMDAwMDAwMDAwMDAwMDAwMDAxMDAwMCwyMzsxMTksMDAwMDAwMDAwMDAwMDAwMDAwMTAxMDAwMDAsMjM7MTI1LDExLDIzOzQ0LDExLDQwOzEsMTAxLDQwOzIsMSw0MDszLDEsNDA7MTAyLDEsNDA6Mjc6Ojo2MDM5ODU0NDg6MTcyODI2MzUyMjo6OjE2MzQ1NjY5ODA6NjA0ODAwOjA6MTI4OGMyYzVhNjQ4OTBmNDM2MDE0YWM4NDkzMjA3ODFmOmRlZmF1bHRfNDox",
        "userid": "603985448",
        "u_name": "%BE%B0%D0%D0pM",
        "escapename": "%25u666f%25u884cpM",
        "ticket": "0ace7c286307aca34a80cbe0fb1d75a6",
        "user_status": "0",
        "utk": "9f7d91056c3e5b72e2559a2b45ba1e17",
        "reviewJump": "nojump",
        "searchGuide": "sg",
        "usersurvey": "1",
        "v": "A1DK4qi1A9ChlN_UVszdo2J-J5WnGTRlVv2IZ0ohHKt-hf6L8ikE86YNWPSZ",
        "reviewJumphk": "nojump"
    }

    response = requests.get(url, headers=headers, cookies=cookies)
    soup = BeautifulSoup(response.text, "lxml")

    table_data_list = soup.find(attrs={'class': 'm_table'}).find_all('td')
    # 初始化一个空的字典，用于存储数据
    data = {}
    # 遍历每个单元格
    for cell in table_data_list:
        try:
            # 提取标题和内容
            strong_tag = cell.find('strong')
            span_tag = cell.find('span')

            if strong_tag and span_tag:
                key = strong_tag.get_text(strip=True).replace('：', '')  # 获取标题
                value = span_tag.get_text(strip=True)  # 获取内容

                # 将数据添加到字典中
                data[key] = value
        except BaseException as e:
            logger.error("转换公司信息异常:{}", e)

    # 将字典转换为 DataFrame
    company_hk_df = pd.DataFrame([data])
    company_hk_df.rename(columns={
        '公司名称': "company_name",
        '注册地址': "registered_address",
        '英文名称': "english_name",
        '所属行业': "industry",
        '公司成立日期 ': "list_date",
        '公司网址': "company_web_site",
        '主营业务': "main_business",
        '董 事 长': "chairman",
        '证券事务代表': "securities_representative",
        '员工人数': "employees",
        '核 数 师 ': "auditor",
        '法律顾问': "legal_adviser",
        '年 结 日 ': "closing_date",
        '电\u3000\u3000话': "telephone",
        '传\u3000\u3000真': "fax",
        '电\u3000\u3000邮': "e_mail",
        '办公地址': "office_address"
    }, inplace=True)
    company_detail = soup.find(attrs={'class': 'yellow tip lh24'})

    soup = BeautifulSoup(company_detail.next, 'html.parser')
    text = soup.text
    company_hk_df['company_detail'] = text
    company_hk_df['symbol'] = symbol_copy
    return company_hk_df


from mns_common.db.MongodbUtil import MongodbUtil

mongodb_util = MongodbUtil('27017')
if __name__ == '__main__':
    stock_account_info = mongodb_util.find_query_data('stock_account_info', {"type": "ths_cookie", })
    ths_cookie_test = list(stock_account_info['cookie'])[0]
    company_hk_df_test = get_hk_company_info('00839', ths_cookie_test)
    print(company_hk_df_test)




import pandas as pd
import mns_common.utils.data_frame_util as data_frame_util

# 获取所有股票实时行情数据    f33,委比
def rename_real_time_quotes_df(temp_df):
    temp_df = temp_df.rename(columns={
        "f2": "now_price",
        "f3": "chg",
        "f5": "volume",
        "f6": "amount",
        "f8": "exchange",
        "f10": "quantity_ratio",
        "f22": "up_speed",
        "f11": "up_speed_05",
        "f12": "symbol",
        "f14": "name",
        "f15": "high",
        "f16": "low",
        "f17": "open",
        "f18": "yesterday_price",
        "f20": "total_mv",
        "f21": "flow_mv",
        "f26": "list_date",
        "f33": "wei_bi",
        "f34": "outer_disk",
        "f35": "inner_disk",
        "f62": "today_main_net_inflow",
        "f66": "super_large_order_net_inflow",
        "f69": "super_large_order_net_inflow_ratio",
        "f72": "large_order_net_inflow",
        # "f78": "medium_order_net_inflow",
        # "f84": "small_order_net_inflow",
        "f100": "industry",
        # "f103": "concept",
        "f184": "today_main_net_inflow_ratio",
        "f352": "average_price",
        "f211": "buy_1_num",
        "f212": "sell_1_num"
    })
    if data_frame_util.is_empty(temp_df):
        return pd.DataFrame()
    else:
        temp_df.loc[temp_df['buy_1_num'] == '-', 'buy_1_num'] = 0
        temp_df.loc[temp_df['sell_1_num'] == '-', 'sell_1_num'] = 0
        temp_df.loc[temp_df['up_speed_05'] == '-', 'up_speed_05'] = 0
        temp_df.loc[temp_df['up_speed'] == '-', 'up_speed'] = 0
        temp_df.loc[temp_df['average_price'] == '-', 'average_price'] = 0
        temp_df.loc[temp_df['wei_bi'] == '-', 'wei_bi'] = 0
        temp_df.loc[temp_df['yesterday_price'] == '-', 'yesterday_price'] = 0
        temp_df.loc[temp_df['now_price'] == '-', 'now_price'] = 0
        temp_df.loc[temp_df['chg'] == '-', 'chg'] = 0
        temp_df.loc[temp_df['volume'] == '-', 'volume'] = 0
        temp_df.loc[temp_df['amount'] == '-', 'amount'] = 0
        temp_df.loc[temp_df['exchange'] == '-', 'exchange'] = 0
        temp_df.loc[temp_df['quantity_ratio'] == '-', 'quantity_ratio'] = 0
        temp_df.loc[temp_df['high'] == '-', 'high'] = 0
        temp_df.loc[temp_df['low'] == '-', 'low'] = 0
        temp_df.loc[temp_df['open'] == '-', 'open'] = 0
        temp_df.loc[temp_df['total_mv'] == '-', 'total_mv'] = 0
        temp_df.loc[temp_df['flow_mv'] == '-', 'flow_mv'] = 0
        temp_df.loc[temp_df['inner_disk'] == '-', 'inner_disk'] = 0
        temp_df.loc[temp_df['outer_disk'] == '-', 'outer_disk'] = 0
        temp_df.loc[temp_df['today_main_net_inflow_ratio'] == '-', 'today_main_net_inflow_ratio'] = 0
        temp_df.loc[temp_df['today_main_net_inflow'] == '-', 'today_main_net_inflow'] = 0
        temp_df.loc[temp_df['super_large_order_net_inflow'] == '-', 'super_large_order_net_inflow'] = 0
        temp_df.loc[temp_df['super_large_order_net_inflow_ratio'] == '-', 'super_large_order_net_inflow_ratio'] = 0
        temp_df.loc[temp_df['large_order_net_inflow'] == '-', 'large_order_net_inflow'] = 0
        # temp_df.loc[temp_df['medium_order_net_inflow'] == '-', 'medium_order_net_inflow'] = 0
        # temp_df.loc[temp_df['small_order_net_inflow'] == '-', 'small_order_net_inflow'] = 0

        temp_df["list_date"] = pd.to_numeric(temp_df["list_date"], errors="coerce")
        temp_df["wei_bi"] = pd.to_numeric(temp_df["wei_bi"], errors="coerce")
        temp_df["average_price"] = pd.to_numeric(temp_df["average_price"], errors="coerce")
        temp_df["yesterday_price"] = pd.to_numeric(temp_df["yesterday_price"], errors="coerce")
        temp_df["now_price"] = pd.to_numeric(temp_df["now_price"], errors="coerce")
        temp_df["chg"] = pd.to_numeric(temp_df["chg"], errors="coerce")
        temp_df["volume"] = pd.to_numeric(temp_df["volume"], errors="coerce")
        temp_df["amount"] = pd.to_numeric(temp_df["amount"], errors="coerce")
        temp_df["exchange"] = pd.to_numeric(temp_df["exchange"], errors="coerce")
        temp_df["quantity_ratio"] = pd.to_numeric(temp_df["quantity_ratio"], errors="coerce")
        temp_df["high"] = pd.to_numeric(temp_df["high"], errors="coerce")
        temp_df["low"] = pd.to_numeric(temp_df["low"], errors="coerce")
        temp_df["open"] = pd.to_numeric(temp_df["open"], errors="coerce")
        temp_df["total_mv"] = pd.to_numeric(temp_df["total_mv"], errors="coerce")
        temp_df["flow_mv"] = pd.to_numeric(temp_df["flow_mv"], errors="coerce")
        temp_df["outer_disk"] = pd.to_numeric(temp_df["outer_disk"], errors="coerce")
        temp_df["inner_disk"] = pd.to_numeric(temp_df["inner_disk"], errors="coerce")
        temp_df["today_main_net_inflow"] = pd.to_numeric(temp_df["today_main_net_inflow"], errors="coerce")
        temp_df["super_large_order_net_inflow"] = pd.to_numeric(temp_df["super_large_order_net_inflow"],
                                                                errors="coerce")
        temp_df["super_large_order_net_inflow_ratio"] = pd.to_numeric(temp_df["super_large_order_net_inflow_ratio"],
                                                                      errors="coerce")
        temp_df["large_order_net_inflow"] = pd.to_numeric(temp_df["large_order_net_inflow"],
                                                          errors="coerce")
        # temp_df["medium_order_net_inflow"] = pd.to_numeric(temp_df["medium_order_net_inflow"],
        #                                                    errors="coerce")
        # temp_df["small_order_net_inflow"] = pd.to_numeric(temp_df["small_order_net_inflow"], errors="coerce")

        # 大单比例
        temp_df['large_order_net_inflow_ratio'] = round((temp_df['large_order_net_inflow'] / temp_df['amount']) * 100,
                                                        2)

        # 外盘是内盘倍数
        temp_df['disk_ratio'] = round((temp_df['outer_disk'] - temp_df['inner_disk']) / temp_df['inner_disk'], 2)
        # 只有外盘没有内盘
        temp_df.loc[temp_df["inner_disk"] == 0, ['disk_ratio']] = 1688
        temp_df = temp_df.sort_values(by=['chg'], ascending=False)
        return temp_df



from mns_common.db.MongodbUtil import MongodbUtil
import requests
import json
import pandas as pd
from concurrent.futures import ThreadPoolExecutor
import datetime
from loguru import logger
import mns_common.component.proxies.proxy_common_api as proxy_common_api
import mns_common.api.em.real_time.east_money_stock_common_rename as east_money_stock_common_rename_api

mongodb_util = MongodbUtil('27017')
fields = ("f352,f2,f3,f5,f6,f8,f10,f11,f22,f12,f14,f15,f16,f17,"
          "f18,f20,f21,f26,f33,f34,f35,f62,f66,f69,f72,f100,f184,f211,f212"),
fs = "m:0 t:6,m:0 t:80,m:1 t:2,m:1 t:23,m:0 t:81 s:2048"
# 最大返回条数
max_number = 5800
# 最小返回条数
min_number = 5600
# 分页条数
PAGE_SIZE = 100


def all_stock_ticker_data_new(initial_proxies, time_out) -> pd.DataFrame:
    """
    使用多线程获取所有股票数据，失败页面会使用新IP重试，最多使用10个IP
    """
    per_page = PAGE_SIZE
    total_pages = (max_number + per_page - 1) // per_page  # 向上取整
    all_pages = set(range(1, total_pages + 1))  # 所有需要获取的页码
    success_pages = set()  # 成功获取的页码
    results = []  # 存储成功获取的数据
    used_ip_count = 1  # 已使用IP计数器（初始IP算第一个）
    MAX_IP_LIMIT = 10  # IP使用上限

    # 循环处理直到所有页面成功或达到IP上限
    while (all_pages - success_pages) and (used_ip_count < MAX_IP_LIMIT):
        # 获取当前需要处理的失败页码
        current_failed_pages = all_pages - success_pages
        if used_ip_count > 1:
            logger.info("当前需要处理的失败页码: {}, 已使用IP数量: {}/{}", current_failed_pages, used_ip_count,
                        MAX_IP_LIMIT)

        # 首次使用初始代理，后续获取新代理
        if len(success_pages) == 0:
            proxies = initial_proxies
        else:
            # 每次重试前获取新代理并计数
            # logger.info("获取新代理IP处理失败页面")
            new_proxy_ip = proxy_common_api.generate_proxy_ip_api(1)
            proxies = {"https": new_proxy_ip}
            # logger.info("新代理IP: {}, 已使用IP数量: {}/{}", new_proxy_ip, used_ip_count + 1, MAX_IP_LIMIT)
            used_ip_count += 1  # 增加IP计数器

        # 创建线程池处理当前失败的页码
        with ThreadPoolExecutor(max_workers=10) as executor:
            futures = {
                executor.submit(get_stock_page_data, pn, proxies, PAGE_SIZE, time_out): pn
                for pn in current_failed_pages
            }

            # 收集结果并记录成功页码
            for future, pn in futures.items():
                try:
                    result = future.result()
                    if not result.empty:
                        results.append(result)
                        success_pages.add(pn)
                    # else:
                    #     logger.warning("页码 {} 未返回有效数据", pn)
                except Exception as e:
                    continue
                    # logger.error("页码 {} 处理异常: {}", pn, str(e))

    # 检查是否达到IP上限
    if used_ip_count >= MAX_IP_LIMIT and (all_pages - success_pages):
        remaining_pages = all_pages - success_pages
        logger.warning("已达到最大IP使用限制({}个)，剩余未获取页码: {}, 返回现有数据", MAX_IP_LIMIT, remaining_pages)

    # 合并所有成功获取的数据
    if results:
        return pd.concat(results, ignore_index=True)
    else:
        return pd.DataFrame()


def get_stock_page_data(pn, proxies, page_size, time_out):
    """获取单页股票数据"""
    current_time = datetime.datetime.now()
    current_timestamp_ms = int(current_time.timestamp() * 1000)

    url = "https://33.push2.eastmoney.com/api/qt/clist/get"
    params = {
        "cb": "jQuery1124046660442520420653_" + str(current_timestamp_ms),
        "pn": str(pn),
        "pz": str(page_size),
        "po": "0",
        "np": "3",
        "ut": "bd1d9ddb04089700cf9c27f6f7426281",
        "fltt": "2",
        "invt": "2",
        "wbp2u": "|0|0|0|web",
        "fid": "f12",
        "fs": fs,
        "fields": fields,
        "_": current_timestamp_ms
    }

    try:
        if proxies is None:
            r = requests.get(url, params, timeout=time_out)
        else:
            r = requests.get(url, params, proxies=proxies, timeout=time_out)

        if r.status_code != 200:
            return pd.DataFrame()

        data_text = r.text
        begin_index = data_text.index('[')
        end_index = data_text.index(']')
        data_json = data_text[begin_index:end_index + 1]
        data_json = json.loads(data_json)

        if not data_json:
            return pd.DataFrame()

        result_df = pd.DataFrame(data_json)
        result_df['page_number'] = pn
        return result_df
    except Exception as e:
        return pd.DataFrame()


def get_real_time_quotes_all_stocks(proxies, time_out):
    page_df = all_stock_ticker_data_new(proxies, time_out)
    page_df = east_money_stock_common_rename_api.rename_real_time_quotes_df(page_df)
    page_df.drop_duplicates('symbol', keep='last', inplace=True)
    return page_df


if __name__ == '__main__':
    while True:
        # 调用方式
        proxy_ip = proxy_common_api.generate_proxy_ip_api(1)
        proxy = {"https": proxy_ip}
        df = get_real_time_quotes_all_stocks(proxy, 5)
        logger.info("数据条数,{}", df.shape[0])



from enum import Enum


class StrategyClassify(Enum):
    # 731 到无穷天的股票 kc
    KC_NORMAL = ('kc_normal', 'kc_normal')

    # 365 到730的股票 kc
    KC_NORMAL_SUB = ('kc_normal_sub', 'kc_normal_sub')

    # 100 到 365 天的股票 kc
    KC_SUB = ('kc_sub', 'kc_sub')

    # 6 到 100的股票 kc
    KC_SUB_NEW = ('kc_sub_new', 'kc_sub_new')

    # 731 到无穷天的股票 sh
    SH_NORMAL = ('sh_normal', 'sh_normal')

    # 365 到730的股票 sh
    SH_NORMAL_SUB = ('sh_normal_sub', 'sh_normal_sub')

    # 100 到 365天的股票 sh
    SH_SUB = ('sh_sub', 'sh_sub')

    # 6 到 100的股票 sh
    SH_SUB_NEW = ('sh_sub_new', 'sh_sub_new')

    # 北交所股票 普通
    BJS_NORMAL = ('bjs_normal', 'bjs_normal')

    # 北交所股票 次新
    BJS_SUB_NEW = ('bjs_sub_new', 'bjs_sub_new')

    # 上市交易 1-5天的股票
    NEW_STOCK = ('new_stock', 'new_stock')

    # 集合竞价 高外盘买入 科创
    HIGH_OUT_DISK_BUY_KC = ('high_out_disk_buy_kc', 'high_out_disk_buy_kc')

    # 集合竞价 高外盘买入 沪深
    HIGH_OUT_DISK_BUY_SH = ('high_out_disk_buy_sh', 'high_out_disk_buy_sh')

    # 集合竞价 高外盘买入 北交所
    HIGH_OUT_DISK_BUY_BJS = ('high_out_disk_buy_bjs', 'high_out_disk_buy_bjs')

    # 所有策略
    ALL = ('all', '所有')

    def __init__(self, strategy_code, strategy_name):
        self.strategy_name = strategy_name
        self.strategy_code = strategy_code


# 获取策略分类
def get_strategy_classify(strategy_code, data_choose_df):
    return data_choose_df.loc[data_choose_df['strategy_code'] == strategy_code]


class StrategyTimePeriod(Enum):
    # 第一阶段
    FIRST_PERIOD = ('first_period', 'first_period')
    # 第二阶段
    SECOND_PERIOD = ('second_period', 'second_period')
    # 第三阶段
    THIRD_PERIOD = ('third_period', 'third_period')
    # 集合竞价阶段
    CALL_AUCTION_PERIOD = ('call_auction_period', 'call_auction_period')

    def __init__(self, time_code, time_name):
        self.time_name = time_name
        self.time_code = time_code



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 16
project_path = file_path[0:end]
sys.path.append(project_path)

import requests


def company_product_area_industry(symbol, market, date):
    if date is None:
        url = (
            f"https://basic.10jqka.com.cn/basicapi/operate/index/v1/product_index_query/?code={symbol}&market={market}"
            f"&type=stock&account=1&timeField=date&analysisTypes=product,area,industry&sortIndex=income&currency=CNY&level=1&expands=product_introduction&locale=zh_CN")
    else:

        url = (
            f"https://basic.10jqka.com.cn/basicapi/operate/index/v1/product_index_query/?code={symbol}&market={market}&date={date}"
            f"&type=stock&account=1&timeField=date&analysisTypes=product,area,industry&sortIndex=income&currency=CNY&level=1&expands=product_introduction&locale=zh_CN")

    headers = {
        "Accept": "text/html,application/xhtml+xml,application/xml;q=0.9,image/avif,image/webp,image/apng,*/*;q=0.8,application/signed-exchange;v=b3;q=0.7",
        "Accept-Language": "zh-CN,zh;q=0.9",
        "Cache-Control": "max-age=0",
        "Connection": "keep-alive",
        "Sec-Fetch-Dest": "document",
        "Sec-Fetch-Mode": "navigate",
        "Sec-Fetch-Site": "cross-site",
        "Sec-Fetch-User": "?1",
        "Upgrade-Insecure-Requests": "1",
        "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/129.0.0.0 Safari/537.36",
        "sec-ch-ua": "\"Google Chrome\";v=\"129\", \"Not=A?Brand\";v=\"8\", \"Chromium\";v=\"129\"",
        "sec-ch-ua-mobile": "?0",
        "sec-ch-ua-platform": "\"Windows\"",
    }

    response = requests.get(url, headers=headers)
    data_json = response.json()
    data_list = data_json['data']
    return data_list


if __name__ == '__main__':
    company_product_area_industry('688551', '17', None)



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 16
project_path = file_path[0:end]
sys.path.append(project_path)

# db_name

EXTRA_INCOME = 'extraIncome'

# us_stock 美股信息数据表
US_STOCK = 'us_stock'
# a股数据表
A_STOCK = 'a_stock'
# hk股票数据
HK_STOCK = 'hk_stock'

# 东方财富a股信息
EM_A_STOCK_INFO = 'em_a_stock_info'

# 东方财富A股 ETF信息
EM_ETF_INFO = 'em_etf_info'

# 东方财富A股 KZZ信息
EM_KZZ_INFO = 'em_kzz_info'

# 东方财富HK股信息
EM_HK_STOCK_INFO = 'em_hk_stock_info'

# 东方财富US股信息
EM_US_STOCK_INFO = 'em_us_stock_info'

# 东方财富US ETF信息
EM_US_ETF_INFO = 'em_us_etf_info'

# 创业板分钟集合数据
ONE_MINUTE_K_LINE_BFQ_C = 'one_minute_k_line_bfq_c'

# 北交所分钟集合数据
ONE_MINUTE_K_LINE_BFQ_BJ = 'one_minute_k_line_bfq_bj'

# 上海主板分钟集合数据
ONE_MINUTE_K_LINE_BFQ_H = 'one_minute_k_line_bfq_h'

# 科创板分钟集合数据
ONE_MINUTE_K_LINE_BFQ_K = 'one_minute_k_line_bfq_k'

# 深圳主板分钟集合数据
ONE_MINUTE_K_LINE_BFQ_S = 'one_minute_k_line_bfq_s'

# 可转债分钟集合数据
ONE_MINUTE_K_LINE_BFQ_KZZ = 'one_minute_k_line_bfq_kzz'

# ETF分钟集合数据
ONE_MINUTE_K_LINE_BFQ_ETF = 'one_minute_k_line_bfq_etf'

# 沪深主要指数分钟集合数据
ONE_MINUTE_K_LINE_BFQ_MAIN_INDEX = 'one_minute_k_line_bfq_main_index'
# 沪深主要指数前复权k线
INDEX_QFQ_DAILY = 'index_qfq_daily'

# 可转债qfq 日k线
KZZ_QFQ_DAILY = 'kzz_qfq_daily'
# ETF qfq 日k线
ETF_QFQ_DAILY = 'etf_qfq_daily'

# 一分钟同步失败集合

ONE_MINUTE_SYNC_FAIL = 'one_minute_sync_fail'

# us stock daily_k_line

US_STOCK_DAILY_QFQ_K_LINE = 'us_stock_daily_qfq_k_line'

US_STOCK_DAILY_BFQ_K_LINE = 'us_stock_daily_bfq_k_line'

US_STOCK_DAILY_HFQ_K_LINE = 'us_stock_daily_hfq_k_line'

# us stock 1分钟集合数据
US_STOCK_MINUTE_K_LINE_BFQ = 'us_stock_one_minute_k_line_bfq'

# us etf 1分钟集合数据
US_ETF_MINUTE_K_LINE_BFQ = 'us_etf_one_minute_k_line_bfq'

# us 主要etf 1分钟集合数据
US_MAIN_ETF_MINUTE_K_LINE_BFQ = 'us_main_etf_one_minute_k_line_bfq'

# hk stock daily_k_line
HK_STOCK_DAILY_QFQ_K_LINE = 'hk_stock_daily_qfq_k_line'
# hk stock 1分钟集合数据
HK_STOCK_MINUTE_K_LINE_BFQ = 'hk_stock_one_minute_k_line_bfq'

# hk etf 1分钟集合数据
HK_ETF_MINUTE_K_LINE_BFQ = 'hk_etf_one_minute_k_line_bfq'

# 雪球利润表
XUE_QIU_LRB_INCOME = 'xue_qiu_lrb_income'

# 雪球资产负债表
XUE_QIU_ASSET_DEBT = 'xue_qiu_asset_debt'

# 雪球资产现金流量表
XUE_QIU_CASH_FLOW = 'xue_qiu_cash_flow'



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 16
project_path = file_path[0:end]
sys.path.append(project_path)
import json
import requests

'''

'''


def trade_buy(symbol, buy_price, buy_volume, terminal):
    '''
    买入
    :param symbol:
    :param buy_price:
    :param buy_volume:
    :param terminal:
    :return:
    '''
    param_buy = {
        'symbol': symbol,
        'buy_price': buy_price,
        'buy_volume': buy_volume,
        'terminal': terminal}
    param_json = json.dumps(param_buy)
    response = request_trader_post('/buy', param_json)
    if response.status_code != 200:
        buy_result = {"message": '买入失败'}
    else:
        buy_result = response.json()
    return buy_result


def trade_sell(symbol, sell_price, sell_volume, terminal):
    '''
    卖出
    :param symbol:
    :param sell_price:
    :param sell_volume:
    :param terminal:
    :return:
    '''
    param_sell = {
        'symbol': symbol,
        'sell_price': sell_price,
        'sell_volume': sell_volume,
        'terminal': terminal}
    param_json = json.dumps(param_sell)
    response = request_trader_post('/sell', param_json)
    if response.status_code != 200:
        sell_result = {"message": '卖出失败'}
    else:
        sell_result = response.json()
    return sell_result


def auto_ipo_buy(terminal):
    '''
    自动打新
    :param terminal:
    :return:
    '''
    param_auto_ipo = {
        'terminal': terminal}
    param_json = json.dumps(param_auto_ipo)
    response = request_trader_get('/auto/ipo/buy', param_json)
    if response.status_code != 200:
        result = {"message": '自动打新失败'}
    else:
        result = response.json()
    return result


def get_position(terminal):
    '''
    获取持仓
    :param terminal:
    :return:
    '''
    param_position = {
        'terminal': terminal}
    param_json = json.dumps(param_position)
    response = request_trader_get('/position', param_json)
    if response.status_code != 200:
        result = {"message": '获取持仓失败'}
    else:
        result = response.json()
    return result


def order_cancel(entrust_no, terminal):
    '''
    撤单
       :param entrust_no:
    :param terminal:
    :return:
    '''
    param_cancel = {
        "entrust_no": entrust_no,
        'terminal': terminal}
    param_json = json.dumps(param_cancel)
    response = request_trader_post('/cancel', param_json)
    if response.status_code != 200:
        result = {"message": '撤单失败'}
    else:
        result = response.json()
    return result


# 自动登陆接口
def auto_login(terminal):
    '''
      自动登陆客户端
      :param terminal:
      :return:
      '''
    param_position = {
        'terminal': terminal}
    param_json = json.dumps(param_position)
    response = request_trader_post('/auto/login', param_json)
    if response.status_code != 200:
        result = {"message": '获取持仓失败'}
    else:
        result = response.json()
    return result


def request_trader_post(url, param):
    total_url = "http://127.0.0.1:5002/api/trade" + url
    headers = {
        "Content-Type": "application/json"
    }
    return requests.post(total_url, data=param, headers=headers)


def request_trader_get(url, param):
    total_url = "http://127.0.0.1:5002/api/trade" + url
    headers = {
        "Content-Type": "application/json"
    }
    return requests.get(total_url, data=param, headers=headers)


if __name__ == '__main__':
    # auto_login('qmt')
    # get_position('qmt')
    # terminal_test = 'easy_trader'
    # order_cancel('251145121', terminal_test)
    # get_position(terminal_test)
    # auto_ipo_buy(terminal_test)
    buy_result_test = trade_buy(
        '688693.SH',
        36.39,
        1000,
        'ths')
    entrust_no_test = buy_result_test['entrust_no']
    order_cancel(entrust_no_test, 'ths')
    # trade_sell(
    #     '301314',
    #     35.77,
    #     100,
    #     'easy_trader')



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 16
project_path = file_path[0:end]
sys.path.append(project_path)

import requests

import mns_common.utils.data_frame_util as data_frame_util
import json
import datetime

import threading
from concurrent.futures import ThreadPoolExecutor
import mns_common.component.proxies.proxy_common_api as proxy_common_api
from loguru import logger
import concurrent.futures
import pandas as pd
import time
from concurrent.futures import ThreadPoolExecutor, as_completed
from threading import Lock
import mns_common.api.em.real_time.real_time_quotes_repeat_api as real_time_quotes_repeat_api

#
# fields_02 = "f1,f2,f3,f4,f5,f6,f7,f8,f9,f10,f11,f12,f13,f14,f15,f16,f17,f18,f19,f20,f21,f22,f23,f24,f25,f26,f27,f28,f29,f30,f31,f32,f33,f34,f35,f36,f37,f38,f39,f40,f41,f42,f43,f44,f45,f46,f47,f48,f49,f50,f51,f52,f53,f54,f55,f56,f57,f58,f59,f60,f61,f62,f63,f64,f65,f66,f67,f68,f69,f70,f71,f72,f73,f74,f75,f76,f77,f78,f79,f80,f81,f82,f83,f84,f85,f86,f87,f88,f89,f90,f91,f92,f93,f94,f95,f96,f97,f98,f99,f100,f101,f102,f103,f104,f105,f106,f107,f108" \
#             ",f109,f110,f111,f112,f113,f114,f115,f116,f117,f118,f119,f120,f121,f122,f123,f124,f125,f126,f127,f128,f129,f130,f131,f132,f133,f134,f135,f136,f137,f138,f139,f140,f141,f142,f143,f144,f145,f146,f147,f148,f149,f150,f151,f152,f153,f154,f155,f156,f157,f158,f159,f160,f161,f162,f163,f164,f165,f166,f167,f168,f169,f170,f171,f172,f173,f174,f175,f176,f177,f178,f179,f180,f181,f182,f183,f184,f185,f186,f187,f188,f189,f190,f191,f192,f193,f194,f195,f196,f197,f198,f199,f200" \
#             ",f209,f210,f212,f213,f214,f215,f216,f217,f218,f219,f220,f221,f222,f223,f224,f225,f226,f227,f228,f229,f230,f231,f232,f233,f234,f235,f236,f237,f238,f239,f240,f241,f242,f243,f244,f245,f246,f247,f248,f249,f250,f251,f252,f253,f254,f255,f256,f257,f258,f259,f260,f261,f262,f263,f264,f265,f266,f267,f268,f269,f270,f271,f272,f273,f274,f275,f276,f277,f278,f279,f280,f281,f282,f283,f284,f285,f286,f287,f288,f289,f290,f291,f292,f293,f294,f295,f296,f297,f298,f299,f300" \
#             ",f309,f310,f312,f313,f314,f315,f316,f317,f318,f319,f320,f321,f322,f323,f324,f325,f326,f327,f328,f329,f330,f331,f332,f333,f334,f335,f336,f337,f338,f339,f340,f341,f342,f343,f344,f345,f346,f347,f348,f349,f350,f351,f352,f353,f354,f355,f356,f357,f358,f359,f360,f361,f362,f363,f364,f365,f366,f367,f368,f369,f370,f371,f372,f373,f374,f375,f376,f377,f378,f379,f380,f381,f382,f383,f384,f385,f386,f387,f388,f389,f390,f391,f392,f393,f394,f395,f396,f397,f398,f399,f401"


fs = "m:0 t:6,m:0 t:80,m:1 t:2,m:1 t:23,m:0 t:81 s:2048"

fields = ("f2,f3,f5,f6,f8,"
          "f9,f10,f22,f12,f13,"
          "f14,f15,f16,f17,f18,"
          "f20,f21,f23,f26,f33,"
          "f34,f35,f37,f38,f39,"
          "f62,f64,f65,f67,f68,"
          "f66,f69,f70,f71,f72,"
          "f76,f77,f78,f82,f83,"
          "f84,f102,f184,f100,f103,"
          "f352,f191,f193,f24,f25")

# 最大返回条数
max_number = 5800
# 最小返回条数
min_number = 5600
# 分页条数
page_number = 100


def get_stock_page_data(pn, proxies, page_number, time_out):
    """
    获取单页股票数据
    """
    # 获取当前日期和时间
    current_time = datetime.datetime.now()

    # 将当前时间转换为时间戳（以毫秒为单位）
    current_timestamp_ms = int(current_time.timestamp() * 1000)

    url = "https://13.push2.eastmoney.com/api/qt/clist/get"
    params = {
        "cb": "jQuery1124046660442520420653_" + str(current_timestamp_ms),
        "pn": str(pn),
        "pz": str(page_number),  # 每页最大200条
        "po": "1",
        "np": "3",
        "ut": "bd1d9ddb04089700cf9c27f6f7426281",
        "fltt": "2",
        "invt": "2",
        "wbp2u": "|0|0|0|web",
        "fid": "f3",
        "fs": fs,
        "fields": fields,
        "_": current_timestamp_ms
    }
    try:
        if proxies is None:
            r = requests.get(url, params, timeout=time_out)
        else:
            r = requests.get(url, params, proxies=proxies, timeout=time_out)
        data_text = r.text
        begin_index = data_text.index('[')
        end_index = data_text.index(']')
        data_json = data_text[begin_index:end_index + 1]
        data_json = json.loads(data_json)
        if data_json is None:
            return pd.DataFrame()
        else:
            return pd.DataFrame(data_json)
    except Exception as e:
        logger.error(f"获取第{pn}页股票列表异常: {e}")
        return pd.DataFrame()


def all_stock_ticker_data_new(fields, fs, proxies) -> pd.DataFrame:
    """
    使用多线程获取所有股票数据
    """

    per_page = page_number
    total_pages = (max_number + per_page - 1) // per_page  # 向上取整

    # 创建线程池
    with ThreadPoolExecutor(max_workers=10) as executor:
        # 提交任务，获取每页数据
        futures = [executor.submit(get_stock_page_data, pn, fields, fs, proxies)
                   for pn in range(1, total_pages + 1)]

        # 收集结果
        results = []
        for future in futures:
            result = future.result()
            if not result.empty:
                results.append(result)

    # 合并所有页面的数据
    if results:
        return pd.concat(results, ignore_index=True)
    else:
        return pd.DataFrame()


def get_all_real_time_quotes(proxies):
    # 获取第一页数据
    page_one_df = get_stock_page_data(1, fields, fs, proxies)
    # 数据接口正常返回5600以上的数量
    if page_one_df.shape[0] > min_number:
        page_one_df = rename_real_time_quotes_df(page_one_df)
        return page_one_df
    else:
        page_df = all_stock_ticker_data_new(fields, fs, proxies)
        page_df = rename_real_time_quotes_df(page_df)
        return page_df


# 获取所有股票实时行情数据    f33,委比
def rename_real_time_quotes_df(temp_df):
    temp_df = temp_df.rename(columns={
        "f2": "now_price",
        "f3": "chg",
        "f5": "volume",
        "f6": "amount",
        "f8": "exchange",
        "f9": "pe_ttm",
        "f10": "quantity_ratio",
        "f22": "up_speed",
        "f12": "symbol",
        "f13": "sz_sh",
        "f14": "name",
        "f15": "high",
        "f16": "low",
        "f17": "open",
        "f18": "yesterday_price",
        "f20": "total_mv",
        "f21": "flow_mv",
        "f23": "pb",
        "f26": "list_date",
        "f33": "wei_bi",
        "f34": "outer_disk",
        "f35": "inner_disk",
        "f37": "ROE",
        "f38": "total_share",
        "f39": "flow_share",
        "f62": "today_main_net_inflow",
        "f64": "super_large_order_inflow",
        "f65": "super_large_order_outflow",
        "f67": "super_large_order_inflow_ratio",
        "f68": "super_large_order_outflow_ratio",

        "f66": "super_large_order_net_inflow",
        "f69": "super_large_order_net_inflow_ratio",
        "f70": "large_order_inflow",
        "f71": "large_order_outflow",
        "f72": "large_order_net_inflow",

        "f76": "medium_order_inflow",
        "f77": "medium_order_outflow",
        "f78": "medium_order_net_inflow",
        "f82": "small_order_inflow",
        "f83": "small_order_outflow",

        "f84": "small_order_net_inflow",
        "f102": "area",
        "f184": "today_main_net_inflow_ratio",
        "f100": "industry",
        "f103": "concept",

        "f352": "average_price",
        "f191": "hk_stock_code",
        "f193": "hk_stock_name",
        "f24": "sixty_day_chg",
        "f25": "now_year_chg",
    })
    temp_df.loc[temp_df['sixty_day_chg'] == '-', 'total_share'] = 0

    temp_df.loc[temp_df['now_year_chg'] == '-', 'now_year_chg'] = 0
    temp_df.loc[temp_df['total_share'] == '-', 'total_share'] = 0
    temp_df.loc[temp_df['flow_share'] == '-', 'flow_share'] = 0
    temp_df.loc[temp_df['pe_ttm'] == '-', 'pe_ttm'] = 0
    temp_df.loc[temp_df['up_speed'] == '-', 'up_speed'] = 0
    temp_df.loc[temp_df['average_price'] == '-', 'average_price'] = 0
    temp_df.loc[temp_df['wei_bi'] == '-', 'wei_bi'] = 0
    temp_df.loc[temp_df['yesterday_price'] == '-', 'yesterday_price'] = 0
    temp_df.loc[temp_df['now_price'] == '-', 'now_price'] = 0
    temp_df.loc[temp_df['chg'] == '-', 'chg'] = 0
    temp_df.loc[temp_df['volume'] == '-', 'volume'] = 0
    temp_df.loc[temp_df['amount'] == '-', 'amount'] = 0
    temp_df.loc[temp_df['exchange'] == '-', 'exchange'] = 0
    temp_df.loc[temp_df['quantity_ratio'] == '-', 'quantity_ratio'] = 0
    temp_df.loc[temp_df['high'] == '-', 'high'] = 0
    temp_df.loc[temp_df['low'] == '-', 'low'] = 0
    temp_df.loc[temp_df['open'] == '-', 'open'] = 0
    temp_df.loc[temp_df['total_mv'] == '-', 'total_mv'] = 0
    temp_df.loc[temp_df['flow_mv'] == '-', 'flow_mv'] = 0
    temp_df.loc[temp_df['inner_disk'] == '-', 'inner_disk'] = 0
    temp_df.loc[temp_df['outer_disk'] == '-', 'outer_disk'] = 0
    temp_df.loc[temp_df['today_main_net_inflow_ratio'] == '-', 'today_main_net_inflow_ratio'] = 0
    temp_df.loc[temp_df['today_main_net_inflow'] == '-', 'today_main_net_inflow'] = 0
    temp_df.loc[temp_df['super_large_order_inflow'] == '-', 'super_large_order_inflow'] = 0
    temp_df.loc[temp_df['super_large_order_outflow'] == '-', 'super_large_order_outflow'] = 0
    temp_df.loc[temp_df['super_large_order_net_inflow'] == '-', 'super_large_order_net_inflow'] = 0
    temp_df.loc[temp_df['super_large_order_inflow_ratio'] == '-', 'super_large_order_inflow_ratio'] = 0
    temp_df.loc[temp_df['super_large_order_outflow_ratio'] == '-', 'super_large_order_outflow_ratio'] = 0
    temp_df.loc[temp_df['super_large_order_net_inflow_ratio'] == '-', 'super_large_order_net_inflow_ratio'] = 0

    temp_df.loc[temp_df['large_order_net_inflow'] == '-', 'large_order_net_inflow'] = 0
    temp_df.loc[temp_df['large_order_inflow'] == '-', 'large_order_inflow'] = 0
    temp_df.loc[temp_df['large_order_outflow'] == '-', 'large_order_outflow'] = 0

    temp_df.loc[temp_df['medium_order_net_inflow'] == '-', 'medium_order_net_inflow'] = 0
    temp_df.loc[temp_df['medium_order_outflow'] == '-', 'medium_order_outflow'] = 0
    temp_df.loc[temp_df['medium_order_inflow'] == '-', 'medium_order_inflow'] = 0

    temp_df.loc[temp_df['small_order_inflow'] == '-', 'small_order_inflow'] = 0
    temp_df.loc[temp_df['small_order_outflow'] == '-', 'small_order_outflow'] = 0
    temp_df.loc[temp_df['small_order_net_inflow'] == '-', 'small_order_net_inflow'] = 0

    temp_df["list_date"] = pd.to_numeric(temp_df["list_date"], errors="coerce")
    temp_df["wei_bi"] = pd.to_numeric(temp_df["wei_bi"], errors="coerce")
    temp_df["average_price"] = pd.to_numeric(temp_df["average_price"], errors="coerce")
    temp_df["yesterday_price"] = pd.to_numeric(temp_df["yesterday_price"], errors="coerce")
    temp_df["now_price"] = pd.to_numeric(temp_df["now_price"], errors="coerce")
    temp_df["chg"] = pd.to_numeric(temp_df["chg"], errors="coerce")
    temp_df["volume"] = pd.to_numeric(temp_df["volume"], errors="coerce")
    temp_df["amount"] = pd.to_numeric(temp_df["amount"], errors="coerce")
    temp_df["exchange"] = pd.to_numeric(temp_df["exchange"], errors="coerce")
    temp_df["quantity_ratio"] = pd.to_numeric(temp_df["quantity_ratio"], errors="coerce")
    temp_df["high"] = pd.to_numeric(temp_df["high"], errors="coerce")
    temp_df["low"] = pd.to_numeric(temp_df["low"], errors="coerce")
    temp_df["open"] = pd.to_numeric(temp_df["open"], errors="coerce")
    temp_df["total_mv"] = pd.to_numeric(temp_df["total_mv"], errors="coerce")
    temp_df["flow_mv"] = pd.to_numeric(temp_df["flow_mv"], errors="coerce")
    temp_df["outer_disk"] = pd.to_numeric(temp_df["outer_disk"], errors="coerce")
    temp_df["inner_disk"] = pd.to_numeric(temp_df["inner_disk"], errors="coerce")
    temp_df["today_main_net_inflow"] = pd.to_numeric(temp_df["today_main_net_inflow"], errors="coerce")
    temp_df["super_large_order_net_inflow"] = pd.to_numeric(temp_df["super_large_order_net_inflow"],
                                                            errors="coerce")
    temp_df["super_large_order_net_inflow_ratio"] = pd.to_numeric(temp_df["super_large_order_net_inflow_ratio"],
                                                                  errors="coerce")
    temp_df["large_order_net_inflow"] = pd.to_numeric(temp_df["large_order_net_inflow"],
                                                      errors="coerce")
    temp_df["medium_order_net_inflow"] = pd.to_numeric(temp_df["medium_order_net_inflow"],
                                                       errors="coerce")

    temp_df["small_order_net_inflow"] = pd.to_numeric(temp_df["small_order_net_inflow"], errors="coerce")

    temp_df["pe_ttm"] = pd.to_numeric(temp_df["pe_ttm"], errors="coerce")
    temp_df["total_share"] = pd.to_numeric(temp_df["total_share"], errors="coerce")
    temp_df["flow_share"] = pd.to_numeric(temp_df["flow_share"], errors="coerce")

    temp_df["super_large_order_inflow"] = pd.to_numeric(temp_df["super_large_order_inflow"], errors="coerce")
    temp_df["super_large_order_outflow"] = pd.to_numeric(temp_df["super_large_order_outflow"], errors="coerce")

    temp_df["super_large_order_inflow_ratio"] = pd.to_numeric(temp_df["super_large_order_inflow_ratio"],
                                                              errors="coerce")
    temp_df["super_large_order_outflow_ratio"] = pd.to_numeric(temp_df["super_large_order_outflow_ratio"],
                                                               errors="coerce")

    temp_df["super_large_order_net_inflow"] = pd.to_numeric(temp_df["super_large_order_net_inflow"], errors="coerce")
    temp_df["super_large_order_net_inflow_ratio"] = pd.to_numeric(temp_df["super_large_order_net_inflow_ratio"],
                                                                  errors="coerce")

    temp_df["medium_order_inflow"] = pd.to_numeric(temp_df["medium_order_inflow"], errors="coerce")
    temp_df["medium_order_outflow"] = pd.to_numeric(temp_df["medium_order_outflow"], errors="coerce")

    temp_df["small_order_inflow"] = pd.to_numeric(temp_df["small_order_inflow"], errors="coerce")
    temp_df["small_order_outflow"] = pd.to_numeric(temp_df["small_order_outflow"], errors="coerce")

    outer_disk = temp_df['outer_disk']
    inner_disk = temp_df['inner_disk']
    disk_ratio = (outer_disk - inner_disk) / inner_disk
    temp_df['disk_ratio'] = round(disk_ratio, 2)
    return temp_df


def repeated_acquisition_ask_async(time_out, max_number, num_threads, pages_per_thread):
    per_page = page_number
    total_pages = (max_number + per_page - 1) // per_page  # 向上取整
    result_df = pd.DataFrame()

    # 创建线程锁以确保线程安全
    df_lock = Lock()

    # 计算每个线程处理的页数范围
    def process_page_range(start_page, end_page, thread_id):
        nonlocal result_df
        local_df = pd.DataFrame()
        current_page = start_page
        proxy_ip = proxy_common_api.generate_proxy_ip_api(1)

        while current_page <= end_page and current_page <= total_pages:
            proxies = {"https": proxy_ip, "http": proxy_ip}
            try:
                page_df = get_stock_page_data(current_page, proxies, page_number, time_out)
                if data_frame_util.is_not_empty(page_df):
                    local_df = pd.concat([local_df, page_df])
                    logger.info("线程{}获取页面数据成功: {}", thread_id, current_page)
                    current_page += 1
                else:
                    time.sleep(0.2)
                    proxy_ip = proxy_common_api.generate_proxy_ip_api(1)
                    logger.info("线程{}获取页面数据失败: {}", thread_id, current_page)
            except BaseException as e:
                time.sleep(1)
                proxy_ip = proxy_common_api.generate_proxy_ip_api(1)
                logger.error("线程{}处理页面{}时发生错误: {}", thread_id, current_page, e)

        with df_lock:
            result_df = pd.concat([result_df, local_df])
        return len(local_df)

    # 计算每个线程的页面范围
    page_ranges = []
    for i in range(num_threads):
        start_page = i * pages_per_thread + 1
        end_page = (i + 1) * pages_per_thread
        if start_page > total_pages:
            break
        page_ranges.append((start_page, end_page, i + 1))

    # 使用线程池执行任务
    with concurrent.futures.ThreadPoolExecutor(max_workers=num_threads) as executor:
        # 提交所有任务
        futures = [
            executor.submit(process_page_range, start, end, tid)
            for start, end, tid in page_ranges
        ]

        # 等待所有任务完成并获取结果
        results = []
        for future in concurrent.futures.as_completed(futures):
            try:
                result = future.result()
                results.append(result)
            except Exception as e:
                logger.error("线程执行出错: {}", e)

    return rename_real_time_quotes_df(result_df)


def get_stock_real_time_quotes(time_out, pages_per_thread):
    try_numer = 3
    while try_numer > 0:
        proxy_ip = proxy_common_api.generate_proxy_ip_api(1)
        proxies = {"https": proxy_ip,
                   "http": proxy_ip}

        total_number = real_time_quotes_repeat_api.get_stocks_num(1, proxies, 20, time_out)
        if total_number > 0:
            break
        try_numer = try_numer - 1
    if total_number == 0:
        return pd.DataFrame()

    total_pages = (max_number + page_number - 1) // page_number  # 向上取整

    num_threads = int((total_pages / pages_per_thread) + 1)
    return repeated_acquisition_ask_async(time_out, max_number, num_threads, pages_per_thread)


# 示例调用
if __name__ == "__main__":
    number = 1
    while True:
        df = get_all_real_time_quotes(None)
        zt_df = df.loc[df['wei_bi'] == 100]
        logger.info("同步次数,{}", number)
        number = number + 1



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 16
project_path = file_path[0:end]
sys.path.append(project_path)

import mns_common.api.proxies.liu_guan_proxy_api as liu_guan_proxy_api
import pandas as pd
import mns_common.utils.data_frame_util as data_frame_util
from mns_common.db.MongodbUtil import MongodbUtil
import mns_common.constant.db_name_constant as db_name_constant
import datetime
import time
from loguru import logger
from functools import lru_cache
import mns_common.api.em.real_time.east_money_stock_a_api as east_money_stock_a_api
import threading

mongodb_util = MongodbUtil('27017')

IP_POOL = 'ip_pool'
ONE_IP = 'one_ip'
query_one = {'ip_type': ONE_IP}
query_pool = {'ip_type': IP_POOL}


def query_liu_guan_proxy_ip():
    ip_proxy_pool = mongodb_util.find_query_data(db_name_constant.IP_PROXY_POOL, query_one)
    return ip_proxy_pool


def remove_one_proxy_ip():
    mongodb_util.remove_data(query_one, db_name_constant.IP_PROXY_POOL)


def check_valid(ip_proxy_pool):
    effect_time = list(ip_proxy_pool['effect_time'])[0]
    now_date = datetime.datetime.now()
    str_now_date = now_date.strftime('%Y-%m-%d %H:%M:%S')
    if effect_time > str_now_date:
        return True
    else:
        remove_one_proxy_ip()
        return False


@lru_cache(maxsize=None)
def get_account_cache():
    query = {"type": "liu_guan_proxy"}
    return mongodb_util.find_query_data(db_name_constant.STOCK_ACCOUNT_INFO, query)


def generate_proxy_ip_api(minutes):
    try_numer = 3
    while try_numer > 0:
        try:
            stock_account_info = get_account_cache()
            order_id = list(stock_account_info['password'])[0]
            secret = list(stock_account_info['account'])[0]
            # 获取10分钟动态ip
            liu_guan_ip = liu_guan_proxy_api.get_proxy_api(order_id, secret, str(60 * minutes))
            try_numer = try_numer
            logger.info("生成新的ip:{}", liu_guan_ip)
            return liu_guan_ip
        except BaseException as e:
            logger.error("获取ip失败:{}", str(e))
            time.sleep(1)
            continue


def generate_proxy_ip(minutes):
    ip_proxy_pool = query_liu_guan_proxy_ip()
    if data_frame_util.is_not_empty(ip_proxy_pool):
        return list(ip_proxy_pool['ip'])[0]
    else:
        remove_one_proxy_ip()
        now_date = datetime.datetime.now()
        # 加上分钟
        time_to_add = datetime.timedelta(minutes=minutes)
        new_date = now_date + time_to_add
        str_now_date = new_date.strftime('%Y-%m-%d %H:%M:%S')
        try:
            ip_proxy = generate_proxy_ip_api(minutes)

            result_dict = {"_id": ip_proxy,
                           'ip_type': ONE_IP,
                           'effect_time': str_now_date,
                           'ip': ip_proxy}
            result_df = pd.DataFrame(result_dict, index=[1])

            mongodb_util.insert_mongo(result_df, db_name_constant.IP_PROXY_POOL)
        except BaseException as e:
            logger.error("获取ip失败:{}", str(e))

        return ip_proxy


def get_proxy_ip(minutes):
    ip_proxy_pool = query_liu_guan_proxy_ip()
    if data_frame_util.is_empty(ip_proxy_pool):
        return generate_proxy_ip(minutes)
    else:
        if check_valid(ip_proxy_pool):
            return list(ip_proxy_pool['ip'])[0]
        else:
            return generate_proxy_ip(minutes)


#
# def check_proxy(proxy_ip):
#     try:
#         # 两秒超时
#         test_df = call_with_timeout(get_em_real_time_data, proxy_ip, timeout=2)
#         if data_frame_util.is_not_empty(test_df):
#             logger.info("可用代理ip:{}", proxy_ip)
#             return True
#         else:
#             return False
#     except Exception as e:
#         logger.error("代理ip不可用:{},{}", proxy_ip, e)
#         return False


# 查询ip池子
def query_liu_guan_proxy_ip_pool():
    ip_proxy_pool = mongodb_util.find_query_data(db_name_constant.IP_PROXY_POOL, query_pool)
    return ip_proxy_pool


def remove_proxy_ip_pool():
    mongodb_util.remove_data(query_pool, db_name_constant.IP_PROXY_POOL)


def generate_proxy_ip_pool_api(minutes, ip_num):
    stock_account_info = get_account_cache()
    order_id = list(stock_account_info['password'])[0]
    secret = list(stock_account_info['account'])[0]
    # 获取10分钟动态ip
    ip_pool = liu_guan_proxy_api.get_proxy_pool_api(order_id, secret, str(60 * minutes), ip_num)
    return ip_pool


def get_proxy_ip_pool(minutes, seconds, ip_num):
    ip_proxy_pool = query_liu_guan_proxy_ip_pool()
    if data_frame_util.is_empty(ip_proxy_pool):
        return generate_proxy_ip_pool(minutes, seconds, ip_num)
    else:
        if check_valid(ip_proxy_pool):
            ip_pool = list(ip_proxy_pool['ip_pool'])[0]
            effect_time = list(ip_proxy_pool['effect_time'])[0]
            result = {'ip_pool': ip_pool,
                      'effect_time': effect_time}
            return result
        else:
            # 已经失效 移除ip pool
            remove_proxy_ip_pool()
            # 重新生成
            return generate_proxy_ip_pool(minutes, seconds, ip_num)


# seconds 有效秒数,minutes 需要减1
def generate_proxy_ip_pool(minutes, seconds, ip_num):
    ip_proxy_pool = query_liu_guan_proxy_ip_pool()
    if data_frame_util.is_not_empty(ip_proxy_pool):
        ip_pool = list(ip_proxy_pool['ip_pool'])[0]
        effect_time = list(ip_proxy_pool['effect_time'])[0]


    else:
        remove_proxy_ip_pool()
        now_date = datetime.datetime.now()
        # 加上分钟 少10秒
        time_to_add = datetime.timedelta(minutes=minutes - 1, seconds=seconds)
        new_date = now_date + time_to_add
        effect_time = new_date.strftime('%Y-%m-%d %H:%M:%S')
        ip_pool = generate_proxy_ip_pool_api(minutes, ip_num)
        result_dict = {
            "_id": [IP_POOL],
            'ip_type': [IP_POOL],
            'effect_time': [effect_time],
            'ip_pool': [ip_pool]  # 每个字段都包装成列表
        }
        result_df = pd.DataFrame(result_dict)

        mongodb_util.insert_mongo(result_df, db_name_constant.IP_PROXY_POOL)
    result = {'ip_pool': ip_pool,
              'effect_time': effect_time}
    return result


def get_em_real_time_data(proxy_ip):
    proxies = {
        "http": proxy_ip,
        "https": proxy_ip
    }
    return east_money_stock_a_api.get_stock_page_data(1, proxies, 20, 10)


# 定义一个带超时的函数调用
def call_with_timeout(func, *args, timeout=2, **kwargs):
    # 用于存储函数执行结果
    result = None
    exception = None

    # 定义一个线程目标函数
    def target():
        nonlocal result, exception
        try:
            result = func(*args, **kwargs)
        except Exception as e:
            exception = e

    # 创建线程并启动
    thread = threading.Thread(target=target)
    thread.start()

    # 等待线程完成，最多等待 timeout 秒
    thread.join(timeout)

    # 如果线程仍然存活，说明函数超时了
    if thread.is_alive():
        raise TimeoutError(f"Function exceeded timeout of {timeout} seconds")

    # 如果函数抛出了异常，重新抛出
    if exception is not None:
        raise exception
    return result


@lru_cache(maxsize=None)
def query_province_and_city_info():
    return mongodb_util.find_all_data(db_name_constant.IP_PROXY_CITY_PROVINCE)


def import_province_and_city():
    # 设置文件夹路径
    folder_path = r'E:\province-and-city.xlsx'
    df = pd.read_excel(folder_path)
    df['_id'] = df['cid']

    mongodb_util.save_mongo(df, db_name_constant.IP_PROXY_CITY_PROVINCE)
    return df


if __name__ == "__main__":
    stock_account_info_test = get_account_cache()
    order_id_test = list(stock_account_info_test['password'])[0]
    secret_test = list(stock_account_info_test['account'])[0]
    # 获取10分钟动态ip
    ip = liu_guan_proxy_api.get_proxy_api(order_id_test, secret_test, str(60 * 1))



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 14
project_path = file_path[0:end]
sys.path.append(project_path)
import requests
import pandas as pd
import mns_common.component.common_service_fun_api as common_service_fun_api
from datetime import datetime
import numpy as np


def stock_zh_a_hist(
        symbol: str = "0.000001",
        period: str = 'daily',
        start_date: str = "19700101",
        end_date: str = "22220101",
        adjust: str = "",
        proxies: str = None
) -> pd.DataFrame:
    """
    东方财富网-行情首页-沪深京 A 股-每日行情
    http://quote.eastmoney.com/concept/sh603777.html?from=classic
    :param symbol: 股票代码
    :type symbol: str
    :param period: choice of {'daily', 'weekly', 'monthly'}
    :type period: str
    :param start_date: 开始日期
    :type start_date: str
    :param end_date: 结束日期
    :type end_date: str
    :param adjust: choice of {"qfq": "前复权", "hfq": "后复权", "": "不复权"}
    :type adjust: str
    :param proxies: 代理ip
    :type proxies: str

    :return: 每日行情
    :rtype: pandas.DataFrame
    """
    adjust_dict = {"qfq": "1", "hfq": "2", "": "0"}
    period_dict = {'daily': '101', 'weekly': '102', 'monthly': '103'}
    url = "http://push2his.eastmoney.com/api/qt/stock/kline/get"
    now_date = datetime.now()
    now_time = int(now_date.timestamp() * 1000)
    now_time = str(now_time)

    params = {
        "fields1": "f1,f2,f3,f4,f5,f6",
        "fields2": "f51,f52,f53,f54,f55,f56,f57,f58,f59,f60,f61,f116",
        "ut": "7eea3edcaed734bea9cbfc24409ed989",
        "klt": period_dict[period],
        "fqt": adjust_dict[adjust],
        "secid": symbol,
        "beg": "0",
        "end": "20500000",
        "_": now_time,
    }

    if proxies is None:
        r = requests.get(url, params=params)
    else:
        r = requests.get(url, params=params, proxies=proxies)

    data_json = r.json()
    temp_df = pd.DataFrame([item.split(",") for item in data_json["data"]["klines"]])
    temp_df.columns = [
        "date",
        "open",
        "close",
        "high",
        "low",
        "volume",
        "amount",
        "pct_chg",
        "chg",
        "change",
        "exchange",
    ]

    temp_df['date'] = temp_df['date'].apply(
        lambda x: x.replace("-", ""))
    temp_df.index = temp_df["date"]
    temp_df = temp_df[start_date:end_date]
    temp_df.reset_index(inplace=True, drop=True)
    temp_df['open'] = pd.to_numeric(temp_df['open'])
    temp_df['close'] = pd.to_numeric(temp_df['close'])
    temp_df['high'] = pd.to_numeric(temp_df['high'])
    temp_df['low'] = pd.to_numeric(temp_df['low'])
    temp_df['volume'] = pd.to_numeric(temp_df['volume'])
    temp_df['amount'] = pd.to_numeric(temp_df['amount'])
    temp_df['pct_chg'] = pd.to_numeric(temp_df['pct_chg'])
    temp_df['chg'] = pd.to_numeric(temp_df['chg'])
    temp_df['change'] = pd.to_numeric(temp_df['change'])
    temp_df['exchange'] = pd.to_numeric(temp_df['exchange'])

    temp_df['symbol'] = symbol
    temp_df['_id'] = temp_df['symbol'] + '-' + temp_df['date']
    temp_df['last_price'] = round(((temp_df['close']) / (1 + temp_df['chg'] / 100)), 2)
    temp_df['max_chg'] = round(
        ((temp_df['high'] - temp_df['last_price']) / temp_df['last_price']) * 100, 2)
    temp_df['amount_level'] = round((temp_df['amount'] / common_service_fun_api.HUNDRED_MILLION), 2)
    temp_df['flow_mv'] = round(temp_df['amount'] * 100 / temp_df['exchange'], 2)
    temp_df['flow_mv_sp'] = round(temp_df['flow_mv'] / common_service_fun_api.HUNDRED_MILLION, 2)

    temp_df.replace([np.inf, -np.inf], 0, inplace=True)
    temp_df.fillna(0, inplace=True)
    return temp_df


import mns_common.component.proxies.proxy_common_api as proxy_common_api

if __name__ == '__main__':
    while True:
        proxy_ip = proxy_common_api.get_proxy_ip(5)
        df = stock_zh_a_hist("0.000001",
                             'daily',
                             "19700101",
                             "22220101",
                             "",
                             proxy_ip)
        print(df)



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 16
project_path = file_path[0:end]
sys.path.append(project_path)

import pandas as pd
from loguru import logger
import requests
import time
import mns_common.component.proxies.proxy_common_api as proxy_common_api
import concurrent.futures

from threading import Lock
import mns_common.utils.data_frame_util as data_frame_util

# 分页条数
page_number = 100


def rename_hg_ggt(temp_df):
    temp_df.columns = [
        "序号",
        "-",
        "最新价",
        "涨跌幅",
        "涨跌额",
        "成交量",
        "成交额",
        "-",
        "-",
        "-",
        "-",
        "-",
        "代码",
        "-",
        "名称",
        "最高",
        "最低",
        "今开",
        "昨收",
        "-",
        "-",
        "-",
        "-",
        "-",
        "-",
        "-",
        "-",
        "-",
        "-",
        "-",
        "-",
        "-",
        "-",
        "-",
        "-",
    ]
    temp_df = temp_df[
        [
            "序号",
            "代码",
            "名称",
            "最新价",
            "涨跌额",
            "涨跌幅",
            "今开",
            "最高",
            "最低",
            "昨收",
            "成交量",
            "成交额",
        ]
    ]

    temp_df = temp_df.rename(columns={
        "序号": "index",
        "代码": "symbol",
        "名称": "name",
        "最新价": "now_price",
        "涨跌额": "range",
        "涨跌幅": "chg",
        "今开": "open",
        "最高": "high",
        "最低": "low",
        "昨收": "yesterday_price",
        "成交额": "amount",
        "成交量": "volume",
    })

    return temp_df


# 获取港股通个数
def get_stock_hk_ggt_components_em_count(cookie, pn, proxies, page_size, time_out):
    headers = {
        'Cookie': cookie
    }
    url = "https://33.push2.eastmoney.com/api/qt/clist/get"
    current_timestamp = str(int(round(time.time() * 1000, 0)))
    params = {
        "pn": str(pn),
        "pz": str(page_size),
        "po": "1",
        "np": "2",
        "ut": "bd1d9ddb04089700cf9c27f6f7426281",
        "fltt": "2",
        "fid": "f3",
        "fs": "b:DLMK0146,b:DLMK0144",
        "fields": "f1,f2,f3,f4,f5,f6,f7,f8,f9,f10,f12,f13,f14,f15,f16,f17,f18,f19,f20,f21,f23,f24,"
                  "f25,f26,f22,f33,f11,f62,f128,f136,f115,f152",
        "_": str(current_timestamp),
    }
    try:
        if proxies is None:
            r = requests.get(url, params, timeout=time_out, headers=headers)
        else:
            r = requests.get(url, params, proxies=proxies, timeout=time_out, headers=headers)
        data_json = r.json()
        total_number = int(data_json['data']['total'])
        return total_number
    except Exception as e:
        logger.error("获取港股通列表,实时行情异常:{}", e)
        return 0


# 获取港股通名单 todo 被封以后替换
def stock_hk_ggt_components_em(cookie, pn, proxies, page_size, time_out) -> pd.DataFrame:
    """
    东方财富网-行情中心-港股市场-港股通成份股
    https://quote.eastmoney.com/center/gridlist.html#hk_components
    :return: 港股通成份股
    :rtype: pandas.DataFrame
    """
    headers = {
        'Cookie': cookie
    }
    url = "https://33.push2.eastmoney.com/api/qt/clist/get"
    params = {
        "pn": str(pn),
        "pz": str(page_size),
        "po": "1",
        "np": "2",
        "ut": "bd1d9ddb04089700cf9c27f6f7426281",
        "fltt": "2",
        "fid": "f3",
        "fs": "b:DLMK0146,b:DLMK0144",
        "fields": "f1,f2,f3,f4,f5,f6,f7,f8,f9,f10,f12,f13,f14,f15,f16,f17,f18,f19,f20,f21,f23,f24,"
                  "f25,f26,f22,f33,f11,f62,f128,f136,f115,f152",
        "_": "1639974456250",
    }
    try:
        if proxies is None:
            r = requests.get(url, params=params, timeout=time_out, headers=headers)
        else:
            r = requests.get(url, params=params, proxies=proxies, timeout=time_out, headers=headers)

        data_json = r.json()
        temp_df = pd.DataFrame(data_json["data"]["diff"]).T
        temp_df.reset_index(inplace=True)
        temp_df["index"] = temp_df.index + 1
        return temp_df
    except Exception as e:
        logger.error("获取港股通列表:{}", e)


def repeated_acquisition_ask_hk_gtt_async(em_cookie, time_out, max_number, num_threads, pages_per_thread):
    per_page = page_number
    total_pages = (max_number + per_page - 1) // per_page  # 向上取整
    result_df = pd.DataFrame()

    # 创建线程锁以确保线程安全
    df_lock = Lock()

    # 计算每个线程处理的页数范围
    def process_page_range(start_page, end_page, thread_id):
        nonlocal result_df
        local_df = pd.DataFrame()
        current_page = start_page
        proxy_ip = proxy_common_api.generate_proxy_ip_api(1)

        while current_page <= end_page and current_page <= total_pages:
            proxies = {"https": proxy_ip, "http": proxy_ip}
            try:
                page_df = stock_hk_ggt_components_em(em_cookie, current_page, proxies, page_number, time_out)
                if data_frame_util.is_not_empty(page_df):
                    local_df = pd.concat([local_df, page_df])
                    logger.info("线程{}获取页面数据成功: {}", thread_id, current_page)
                    current_page += 1
                else:
                    time.sleep(0.2)
                    proxy_ip = proxy_common_api.generate_proxy_ip_api(1)
                    logger.info("线程{}获取页面数据失败: {}", thread_id, current_page)
            except BaseException as e:
                time.sleep(1)
                proxy_ip = proxy_common_api.generate_proxy_ip_api(1)
                logger.error("线程{}处理页面{}时发生错误: {}", thread_id, current_page, e)

        with df_lock:
            result_df = pd.concat([result_df, local_df])
        return len(local_df)

    # 计算每个线程的页面范围
    page_ranges = []
    for i in range(num_threads):
        start_page = i * pages_per_thread + 1
        end_page = (i + 1) * pages_per_thread
        if start_page > total_pages:
            break
        page_ranges.append((start_page, end_page, i + 1))

    # 使用线程池执行任务
    with concurrent.futures.ThreadPoolExecutor(max_workers=num_threads) as executor:
        # 提交所有任务
        futures = [
            executor.submit(process_page_range, start, end, tid)
            for start, end, tid in page_ranges
        ]

        # 等待所有任务完成并获取结果
        results = []
        for future in concurrent.futures.as_completed(futures):
            try:
                result = future.result()
                results.append(result)
            except Exception as e:
                logger.error("线程执行出错: {}", e)

    return rename_hg_ggt(result_df)


# 港股通实时行情
def get_ggt_real_time_quotes(em_cookie, time_out, pages_per_thread):
    try_numer = 3
    while try_numer > 0:
        proxy_ip = proxy_common_api.generate_proxy_ip_api(1)
        proxies = {"https": proxy_ip,
                   "http": proxy_ip}

        max_number = get_stock_hk_ggt_components_em_count(em_cookie, 1, proxies, 20, time_out)
        if max_number > 0:
            break
        try_numer = try_numer - 1
    if max_number == 0:
        return pd.DataFrame()

    total_pages = (max_number + page_number - 1) // page_number  # 向上取整

    num_threads = int((total_pages / pages_per_thread) + 1)
    return repeated_acquisition_ask_hk_gtt_async(em_cookie, time_out, max_number, num_threads, pages_per_thread)


import mns_common.component.cookie.cookie_info_service as cookie_info_service

if __name__ == '__main__':
    em_cookie_test = cookie_info_service.get_em_cookie()
    test_df = get_ggt_real_time_quotes(em_cookie_test, 30, 6)
    print(test_df)



import sys
import os
import requests
import threading
from loguru import logger

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 14
project_path = file_path[0:end]
sys.path.append(project_path)
import pandas as pd
import mns_common.api.kpl.symbol.kpl_symbol_common_field_constant as kpl_symbol_common_field_constant

# 定义一个全局锁，用于保护 result 变量的访问
result_lock = threading.Lock()
# 初始化 result 变量为一个空的 Pandas DataFrame
result = pd.DataFrame()

MAX_PAGE_NUMBER = 60


def get_stock_count(str_day, page_number, begin, end):
    index = page_number * MAX_PAGE_NUMBER

    url = "https://apphis.longhuvip.com/w1/api/index.php?" + \
          "Date=" + str_day + \
          "&Filter=0&FilterGem=0&FilterMotherboard=0&FilterTIB=0" + \
          "&Isst=0&Order=1&PhoneOSNew=2" + \
          "&REnd=" + end + \
          "&RStart=" + begin + \
          "&Ratio=6&Type=1&VerSion=5.11.0.3&a=HisRankingInfo_W8&apiv=w33&c=HisStockRanking" + \
          "&index=" + str(index) + \
          "&st=" + str(MAX_PAGE_NUMBER)

    headers = {
        "Content-Type": "application/x-www-form-urlencoded; charset=utf-8"
    }

    r = requests.get(url, headers=headers)
    data_json = r.json()
    return data_json['Count']


def get_stock_quotes_his(str_day, page_number, begin, end):
    global result
    index = page_number * MAX_PAGE_NUMBER

    url = ("https://apphis.longhuvip.com/w1/api/index.php?"
           "Date=" + str_day +
           "&Filter=0&FilterGem=0&FilterMotherboard=0&FilterTIB=0"
           "&Isst=0&Order=1&PhoneOSNew=2"
           "&REnd=" + end +
           "&RStart=" + begin +
           "&Ratio=6&Type=1&VerSion=5.11.0.3&a=HisRankingInfo_W8&apiv=w33&c=HisStockRanking"
           "&index=" + str(index) +
           "&st=" + str(MAX_PAGE_NUMBER)
           )

    headers = {
        "Content-Type": "application/x-www-form-urlencoded; charset=utf-8"
    }

    r = requests.get(url, headers=headers)
    try:
        data_json = r.json()
        data_list = data_json['list']
        data_df = pd.DataFrame(data_list)
    except BaseException as e:
        logger.error("出现异常:{},{},{},{},{}", str_day, page_number, begin, end, e)

    with result_lock:
        # 使用锁来保护 result 变量的访问，将每页的数据添加到结果中
        result = pd.concat([result, data_df], ignore_index=True)


def sync_stock_his_quotes(str_day, begin, end):
    count = get_stock_count(str_day, 0, begin, end)
    global result
    result = pd.DataFrame()  # 重新初始化 result 变量
    threads = []
    page_number = round(count / MAX_PAGE_NUMBER, 0) + 1
    page_number = int(page_number)
    # 创建多个线程来获取数据
    for page in range(page_number):  # 0到100页
        thread = threading.Thread(target=get_stock_quotes_his, args=(str_day, page, begin, end))
        threads.append(thread)
        thread.start()

    # 等待所有线程完成
    for thread in threads:
        thread.join()

    # 返回获取的接口数据
    result.columns = kpl_symbol_common_field_constant.SYNC_FIELD
    result = result[kpl_symbol_common_field_constant.CHOOSE_FIELD]
    result = result.sort_values(by=['chg'], ascending=False)
    return result


def his_test(str_day):
    url = ("https://apphis.longhuvip.com/w1/api/index.php?" + \
           "Date=" + str_day + \
           "&Filter=0&FilterGem=0&FilterMotherboard=0&FilterTIB=0&Isst=0&Order=1&PhoneOSNew=2&REnd=1315&RStart=1045&Ratio=6"
           "&Type=1&VerSion=5.11.0.3&a=HisRankingInfo_W8&apiv=w33&c=HisStockRanking&index=0&st=20")
    headers = {
        "Content-Type": "application/x-www-form-urlencoded; charset=utf-8"
    }

    r = requests.get(url, headers=headers)
    data_json = r.json()
    return data_json['Count']


if __name__ == '__main__':
    # 2021-10-25,45,0925,0955 2023-09-15,11,0925,1005

    # get_stock_quotes_his('2023-09-20', 11, '0925', '1005')
    df = sync_stock_his_quotes('2025-04-18', '0935', '0940')
    get_stock_count('2023-09-14', 0, '0925', '1500')

    his_test('2021-10-20')



from enum import Enum

'''
价格枚举
'''


class CookieEnum(Enum):
    THS_COOKIE = ('ths_cookie', '同花顺cookie')
    EM_COOKIE = ('em_cookie', '东方财富cookie')
    XUE_QIU_COOKIE = ('xue_qiu_cookie', '雪球cookie')

    def __init__(self, cookie_code, cookie_name):
        self.cookie_code = cookie_code
        self.cookie_name = cookie_name



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 16
project_path = file_path[0:end]
sys.path.append(project_path)
import requests
import pandas as pd


# year 年
#  quarter 季度
# month 月度
# week 周
# day 日
def get_xue_qiu_k_line(symbol, period, cookie, end_time, hq):
    url = "https://stock.xueqiu.com/v5/stock/chart/kline.json"

    params = {
        "symbol": symbol,
        "begin": end_time,
        "period": period,
        "type": hq,
        "count": "-120084",
        "indicator": "kline,pe,pb,ps,pcf,market_capital,agt,ggt,balance"
    }

    headers = {
        "accept": "application/json, text/plain, */*",
        "accept-language": "zh-CN,zh;q=0.9",
        "origin": "https://xueqiu.com",
        "priority": "u=1, i",
        "referer": "https://xueqiu.com/S/SZ300879?md5__1038=n4%2BxgDniDQeWqxYwq0y%2BbDyG%2BYDtODuD7q%2BqRYID",
        "sec-ch-ua": '"Chromium";v="134", "Not:A-Brand";v="24", "Google Chrome";v="134"',
        "sec-ch-ua-mobile": "?0",
        "sec-ch-ua-platform": '"Windows"',
        "sec-fetch-dest": "empty",
        "sec-fetch-mode": "cors",
        "sec-fetch-site": "same-site",
        "user-agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/134.0.0.0 Safari/537.36",
        "cookie": cookie
    }

    response = requests.get(
        url=url,
        params=params,
        headers=headers
    )

    if response.status_code == 200:
        response_data = response.json()
        df = pd.DataFrame(
            data=response_data['data']['item'],
            columns=response_data['data']['column']
        )

        # 1. 转换为 datetime（自动处理毫秒级时间戳）
        df["beijing_time"] = pd.to_datetime(df["timestamp"], unit="ms")

        # 2. 设置 UTC 时区
        df["beijing_time"] = df["beijing_time"].dt.tz_localize("UTC")

        # 3. 转换为北京时间（UTC+8）
        df["beijing_time"] = df["beijing_time"].dt.tz_convert("Asia/Shanghai")

        # 4. 提取年月日（格式：YYYY-MM-DD）
        df["str_day"] = df["beijing_time"].dt.strftime("%Y-%m-%d %H:%M:%S")
        del df["beijing_time"]

        return df
    else:
        # 直接抛出带有明确信息的异常
        raise ValueError("调用雪球接口失败")


if __name__ == '__main__':
    number = 1
    cookies ='cookiesu=291756518429127; device_id=8c5eef4332e51dbcbcd92943b0dd91e4; s=bz17174k1c; xq_a_token=b9c7e702181cba3ed732d5019efe2dfe2fb054b0; xqat=b9c7e702181cba3ed732d5019efe2dfe2fb054b0; xq_r_token=c1edaf05e1c6fdf8122671eced8049e8df8a4290; xq_id_token=eyJ0eXAiOiJKV1QiLCJhbGciOiJSUzI1NiJ9.eyJ1aWQiOi0xLCJpc3MiOiJ1YyIsImV4cCI6MTc2MTYxNDEwNywiY3RtIjoxNzU5OTc2NzUxOTI3LCJjaWQiOiJkOWQwbjRBWnVwIn0.JwQMnAT6E1lPSqfK-GnFpLNQz-Jr-xtZ6HoUfnCfeRTNKrDJqf0l5_iY7dhEo6A5m38MmXj0hgR-xYkzPm35fFcQCQnZ06dOK0XCP6AE9r5KVFd73GyqbXLijKDFPQVM0sPgbgCs9fTOmB7Nlju_7B_raPmZ8IIHzZRU6uSK9oXsrnwpo4TD0Mr2nMF3ktVwEQHdkZsjm9mdSZaT9fkDvayFKKmg_O-JbHDZ6mTF1i-zR6oH-5r3g6HJJU9-_NwzZMeBEVnLG8IWwO8_n9CWdpbqQ-qC-iue4yEHFdiTLBCRRgyFauVv0kJS1ZNKvvefxkETTVr-WgXobT82ED7ApA; u=291756518429127; Hm_lvt_1db88642e346389874251b5a1eded6e3=1759765103,1759808830,1759970243,1759976801; HMACCOUNT=4C4F802C04F4D70A; Hm_lpvt_1db88642e346389874251b5a1eded6e3=1759978805'
    while True:
        test_df = get_xue_qiu_k_line('SZ300188', '1m', cookies, '1760065317680', '')
        print(number)
        number = number + 1



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 16
project_path = file_path[0:end]
sys.path.append(project_path)
import pandas as pd
import requests


def stock_k_line_hist(
        symbol: str = "000001",
        period: str = "daily",
        start_date: str = "19700101",
        end_date: str = "20500101",
        adjust: str = "",
        timeout: float = None,
        proxies: str = None
) -> pd.DataFrame:
    """
    东方财富网-行情首页-沪深京 A 股-每日行情
    https://quote.eastmoney.com/concept/sh603777.html?from=classic
    :param symbol: 股票代码
    :type symbol: str
    :param period: choice of {'daily', 'weekly', 'monthly'}
    :type period: str
    :param start_date: 开始date
    :type start_date: str
    :param end_date: 结束date
    :type end_date: str
    :param adjust: choice of {"qfq": "前复权", "hfq": "后复权", "": "不复权"}
    :type adjust: str
    :param timeout: choice of None or a positive float number
    :type timeout: float
    :param proxies: 代理ip
    :type proxies: str

    :return: 每日行情
    :rtype: pandas.DataFrame
    """
    adjust_dict = {"qfq": "1", "hfq": "2", "": "0"}
    period_dict = {"daily": "101", "weekly": "102", "monthly": "103"}
    url = "https://push2his.eastmoney.com/api/qt/stock/kline/get"
    params = {
        "fields1": "f1,f2,f3,f4,f5,f6",
        "fields2": "f51,f52,f53,f54,f55,f56,f57,f58,f59,f60,f61,f116",
        "ut": "7eea3edcaed734bea9cbfc24409ed989",
        "klt": period_dict[period],
        "fqt": adjust_dict[adjust],
        "secid": symbol,
        "beg": start_date,
        "end": end_date,
        "_": "1623766962675",
    }

    if proxies is None:
        r = requests.get(url, params=params, timeout=timeout)
    else:
        r = requests.get(url, params=params, proxies=proxies, timeout=timeout)

    data_json = r.json()
    if not (data_json["data"] and data_json["data"]["klines"]):
        return pd.DataFrame()
    temp_df = pd.DataFrame([item.split(",") for item in data_json["data"]["klines"]])
    temp_df.columns = [
        "date",
        "open",
        "close",
        "high",
        "low",
        "volume",
        "amount",
        "pct_chg",
        "chg",
        "change_price",
        "exchange",
    ]
    temp_df["date"] = pd.to_datetime(temp_df["date"], errors="coerce").dt.date
    temp_df["open"] = pd.to_numeric(temp_df["open"], errors="coerce")
    temp_df["close"] = pd.to_numeric(temp_df["close"], errors="coerce")
    temp_df["high"] = pd.to_numeric(temp_df["high"], errors="coerce")
    temp_df["low"] = pd.to_numeric(temp_df["low"], errors="coerce")
    temp_df["volume"] = pd.to_numeric(temp_df["volume"], errors="coerce")
    temp_df["amount"] = pd.to_numeric(temp_df["amount"], errors="coerce")
    temp_df["pct_chg"] = pd.to_numeric(temp_df["pct_chg"], errors="coerce")
    temp_df["chg"] = pd.to_numeric(temp_df["chg"], errors="coerce")
    temp_df["change_price"] = pd.to_numeric(temp_df["change_price"], errors="coerce")
    temp_df["exchange"] = pd.to_numeric(temp_df["exchange"], errors="coerce")
    temp_df = temp_df[
        [
            "date",
            "open",
            "close",
            "high",
            "low",
            "volume",
            "amount",
            "pct_chg",
            "chg",
            "change_price",
            "exchange",
        ]
    ]
    return temp_df


if __name__ == '__main__':
    stock_k_line_hist(
        "1.513180",
        "daily",
        "19700101",
        "20500101",
        "",
        None,
        None)
